# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: uauth_ext.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from mecord import uauth_common_pb2 as uauth__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fuauth_ext.proto\x12\x08uauth_pb\x1a\x12uauth_common.proto\"m\n\x0cVerifyIAPReq\x12\x11\n\taccountId\x18\x01 \x01(\x03\x12\x0f\n\x07receipt\x18\x02 \x01(\t\x12\x15\n\rtransactionId\x18\x03 \x01(\t\x12\x10\n\x08order_no\x18\x04 \x01(\t\x12\x10\n\x08goods_id\x18\x05 \x01(\t\"\x0e\n\x0cVerifyIAPRes\"a\n\x08GoldCard\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x05\x12\r\n\x05golds\x18\x03 \x01(\x05\x12\x16\n\x0egiveaway_golds\x18\x04 \x01(\x05\x12\x12\n\nidentifier\x18\x05 \x01(\t\"\x10\n\x0eGetGoodListReq\"H\n\x0eGetGoodListRes\x12%\n\tgood_list\x18\x01 \x03(\x0b\x32\x12.uauth_pb.GoldCard\x12\x0f\n\x07version\x18\x02 \x01(\x05\",\n\x0bOrderIAPReq\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x11\n\taccountId\x18\x02 \x01(\x03\"\x1f\n\x0bOrderIAPRes\x12\x10\n\x08order_no\x18\x01 \x01(\t\"M\n\x10\x43loseOrderIAPReq\x12\x10\n\x08order_no\x18\x01 \x01(\t\x12\'\n\x06status\x18\x02 \x01(\x0e\x32\x17.uauth_pb.IAPStatusType\"\x12\n\x10\x43loseOrderIAPRes\"%\n\x17VIPChargeAccountInfoReq\x12\n\n\x02id\x18\x01 \x01(\x03\"\x8d\x01\n\x17VIPChargeAccountInfoRes\x12\x10\n\x08\x64ue_bank\x18\x01 \x01(\t\x12\r\n\x05payee\x18\x02 \x01(\t\x12\x16\n\x0e\x61\x63\x63ount_number\x18\x03 \x01(\t\x12\x14\n\x0c\x64\x65posit_bank\x18\x04 \x01(\t\x12\x10\n\x08nickname\x18\x05 \x01(\t\x12\x11\n\tplayer_id\x18\x06 \x01(\x03\"\x11\n\x0fVIPChargeLogReq\"8\n\x0fVIPChargeLogRes\x12%\n\x04list\x18\x01 \x03(\x0b\x32\x17.uauth_pb.VIPChargeLogs\"C\n\rVIPChargeLogs\x12\x0b\n\x03\x64\x61y\x18\x01 \x01(\t\x12%\n\x04list\x18\x02 \x03(\x0b\x32\x17.uauth_pb.VIPChargeItem\"x\n\rVIPChargeItem\x12\x11\n\tcharge_at\x18\x01 \x01(\x03\x12\x11\n\tfinish_at\x18\x02 \x01(\x03\x12\x0b\n\x03rmb\x18\x03 \x01(\x03\x12\x0c\n\x04gold\x18\x04 \x01(\x03\x12&\n\x06status\x18\x05 \x01(\x0e\x32\x16.uauth_pb.ChargeStatus\"E\n\rReportDataReq\x12&\n\x04type\x18\x01 \x01(\x0e\x32\x18.uauth_pb.ReportDataType\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"\x0f\n\rReportDataRes\"\xf8\x02\n\x0cGetChargeReq\x12\x10\n\x08order_id\x18\x01 \x01(\t\x12\x12\n\naccount_id\x18\x02 \x01(\x03\x12+\n\x08pay_type\x18\x03 \x01(\x0e\x32\x19.uauth_pb.UPayChannelType\x12\x0c\n\x04gold\x18\x04 \x01(\x03\x12\x0e\n\x06remark\x18\x05 \x01(\t\x12\x34\n\x07\x65xtends\x18\x06 \x03(\x0b\x32#.uauth_pb.GetChargeReq.ExtendsEntry\x12\x39\n\nextra_data\x18\x07 \x03(\x0b\x32%.uauth_pb.GetChargeReq.ExtraDataEntry\x12\x10\n\x08sub_type\x18\x08 \x01(\t\x12\x12\n\nreturn_url\x18\t \x01(\t\x1a.\n\x0c\x45xtendsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x30\n\x0e\x45xtraDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"P\n\x0cGetChargeRes\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65tail\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\t\x12\x14\n\x0credirect_url\x18\x04 \x01(\t\"r\n\rGetSmsCodeReq\x12\x0f\n\x07\x63ountry\x18\x01 \x01(\x05\x12\x10\n\x08phone_no\x18\x02 \x01(\t\x12\x12\n\nphone_sign\x18\x03 \x01(\t\x12*\n\x0csms_code_tpl\x18\x04 \x01(\x0e\x32\x14.uauth_pb.SMSCodeTpl\"\x0f\n\rGetSmsCodeRes\"\x85\x01\n\x0eGetSmsTokenReq\x12\x0f\n\x07\x63ountry\x18\x01 \x01(\x05\x12\x10\n\x08phone_no\x18\x02 \x01(\t\x12\x10\n\x08sms_code\x18\x03 \x01(\t\x12\x12\n\nphone_sign\x18\x04 \x01(\t\x12*\n\x0csms_code_tpl\x18\x05 \x01(\x0e\x32\x14.uauth_pb.SMSCodeTpl\"#\n\x0eGetSmsTokenRes\x12\x11\n\tsms_token\x18\x01 \x01(\t\"=\n\x0fPhoneSmsCodeReq\x12*\n\x0csms_code_tpl\x18\x01 \x01(\x0e\x32\x14.uauth_pb.SMSCodeTpl\"\x11\n\x0fPhoneSmsCodeRes\"T\n\x14\x43heckPhoneSmsCodeReq\x12*\n\x0csms_code_tpl\x18\x01 \x01(\x0e\x32\x14.uauth_pb.SMSCodeTpl\x12\x10\n\x08sms_code\x18\x02 \x01(\t\"\x16\n\x14\x43heckPhoneSmsCodeRes\"\xde\x01\n\x0f\x43ommonSignInRes\x12\x13\n\x0blogin_token\x18\x01 \x01(\t\x12\x0e\n\x06is_new\x18\x02 \x01(\x08\x12\x0f\n\x07user_id\x18\x03 \x01(\x12\x12\x37\n\x07\x65xtends\x18\x04 \x03(\x0b\x32&.uauth_pb.CommonSignInRes.ExtendsEntry\x12,\n\nlogin_type\x18\x05 \x01(\x0e\x32\x18.uauth_pb.UauthLoginType\x1a.\n\x0c\x45xtendsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xce\x01\n\x12SignInWithAppleReq\x12\x16\n\x0eidentity_token\x18\x01 \x01(\t\x12\x1a\n\x12\x61uthorization_code\x18\x02 \x01(\t\x12\x11\n\tfull_name\x18\x03 \x01(\t\x12\x11\n\tdevice_id\x18\x04 \x01(\t\x12\x18\n\x10u_meng_device_id\x18\x05 \x01(\t\x12\x13\n\x0byidun_token\x18\x06 \x01(\t\x12/\n\x0e\x64\x65vice_message\x18\x07 \x01(\x0b\x32\x17.uauth_pb.DeviceMessage\"\x95\x01\n\x11IdOrPhoneLoginReq\x12\x0f\n\x07\x63ountry\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\x12\x0c\n\x04sign\x18\x04 \x01(\t\x12\x11\n\tdevice_id\x18\x05 \x01(\t\x12\x18\n\x10u_meng_device_id\x18\x06 \x01(\t\x12\x13\n\x0byidun_token\x18\x07 \x01(\t\"\xa3\x02\n\x14LoginWithPhoneSMSReq\x12\r\n\x05phone\x18\x01 \x01(\t\x12\x11\n\tsms_token\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x04 \x01(\x05\x12\x0f\n\x07\x63hannel\x18\x05 \x01(\x05\x12\x10\n\x08sms_code\x18\x06 \x01(\t\x12\x18\n\x10u_meng_device_id\x18\x08 \x01(\t\x12\x13\n\x0byidun_token\x18\t \x01(\t\x12\x12\n\nphone_sign\x18\n \x01(\t\x12/\n\x0e\x64\x65vice_message\x18\x0b \x01(\x0b\x32\x17.uauth_pb.DeviceMessage\x12*\n\x0csms_code_tpl\x18\x0c \x01(\x0e\x32\x14.uauth_pb.SMSCodeTpl\"\xa0\x02\n\rThirdLoginReq\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x02 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\t\x12\x11\n\tdevice_id\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x05 \x01(\x05\x12\x0f\n\x07\x63hannel\x18\x06 \x01(\x05\x12,\n\nlogin_type\x18\x07 \x01(\x0e\x32\x18.uauth_pb.UauthLoginType\x12\x18\n\x10u_meng_device_id\x18\x08 \x01(\t\x12\x13\n\x0byidun_token\x18\t \x01(\t\x12\x14\n\x0ctoken_secret\x18\n \x01(\t\x12/\n\x0e\x64\x65vice_message\x18\x0b \x01(\x0b\x32\x17.uauth_pb.DeviceMessage\"\xd2\x01\n\x18\x43hinaMobileQuickLoginReq\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x04 \x01(\x05\x12\x0f\n\x07\x63hannel\x18\x05 \x01(\x05\x12\x18\n\x10u_meng_device_id\x18\x06 \x01(\t\x12\x13\n\x0byidun_token\x18\x07 \x01(\t\x12/\n\x0e\x64\x65vice_message\x18\x08 \x01(\x0b\x32\x17.uauth_pb.DeviceMessage\"\xc4\x01\n\x13\x43hinaTelecomAuthReq\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x04 \x01(\x05\x12\x0f\n\x07\x63hannel\x18\x05 \x01(\x05\x12\x18\n\x10u_meng_device_id\x18\x06 \x01(\t\x12\x13\n\x0byidun_token\x18\x07 \x01(\t\x12/\n\x0e\x64\x65vice_message\x18\x08 \x01(\x0b\x32\x17.uauth_pb.DeviceMessage\"\xcd\x01\n\x12UmengQuickLoginReq\x12\x0f\n\x07\x61pp_key\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x04 \x01(\x05\x12\x0f\n\x07\x63hannel\x18\x05 \x01(\x05\x12\x18\n\x10u_meng_device_id\x18\x08 \x01(\t\x12\x13\n\x0byidun_token\x18\t \x01(\t\x12/\n\x0e\x64\x65vice_message\x18\n \x01(\x0b\x32\x17.uauth_pb.DeviceMessage\"\xb4\x01\n\x0b\x44\x65vLoginReq\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x04 \x01(\x05\x12\x0f\n\x07\x63hannel\x18\x05 \x01(\x05\x12\x18\n\x10u_meng_device_id\x18\x06 \x01(\t\x12\x13\n\x0byidun_token\x18\x07 \x01(\t\x12/\n\x0e\x64\x65vice_message\x18\x08 \x01(\x0b\x32\x17.uauth_pb.DeviceMessage\"\x8f\x01\n\x10ResetPasswordReq\x12\x0f\n\x07\x63ountry\x18\x01 \x01(\x05\x12\x10\n\x08phone_no\x18\x02 \x01(\t\x12\x11\n\tsms_token\x18\x03 \x01(\t\x12\x10\n\x08password\x18\x04 \x01(\t\x12\x0c\n\x04sign\x18\x05 \x01(\t\x12\x12\n\nphone_sign\x18\x06 \x01(\t\x12\x11\n\tplayer_id\x18\x07 \x01(\x03\"\x12\n\x10ResetPasswordRes\"\x10\n\x0eLoginSecretReq\"\x1d\n\x0eLoginSecretRes\x12\x0b\n\x03key\x18\x01 \x01(\t\"W\n\x0fUpdatePasswdReq\x12\x12\n\nold_passwd\x18\x01 \x01(\t\x12\x12\n\nnew_passwd\x18\x02 \x01(\t\x12\x0c\n\x04sign\x18\x03 \x01(\t\x12\x0e\n\x06is_new\x18\x04 \x01(\x08\"\x11\n\x0fUpdatePasswdRes\"<\n\tInviteReq\x12\x11\n\tplayer_id\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\x05\x12\x0e\n\x06\x65xtend\x18\x03 \x01(\t\"\x0b\n\tInviteRes\"\x10\n\x0eGetSyncTimeReq\"\x10\n\x0eGetSyncTimeRes\";\n\x14ReportBuyNobilityReq\x12\x0f\n\x07room_id\x18\x01 \x01(\x03\x12\x12\n\nbenefit_id\x18\x02 \x01(\x03\"\x16\n\x14ReportBuyNobilityRes\"\xb3\x01\n\x12GoogleIABNotifyReq\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x14\n\x0cpackage_name\x18\x02 \x01(\t\x12:\n\nbuy_intent\x18\x03 \x01(\x0b\x32&.uauth_pb.GoogleIABNotifyReq.BuyIntent\x1a:\n\tBuyIntent\x12\x15\n\rpurchase_data\x18\x01 \x01(\t\x12\x16\n\x0e\x64\x61ta_signature\x18\x02 \x01(\t\"\x14\n\x12GoogleIABNotifyRes\"M\n\x14GoogleIABProductItem\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05price\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\"\x1a\n\x18GoogleIABProductItemsReq\"I\n\x18GoogleIABProductItemsRes\x12-\n\x05items\x18\x01 \x03(\x0b\x32\x1e.uauth_pb.GoogleIABProductItem\"\x13\n\x11GetWeChatAppIdReq\"#\n\x11GetWeChatAppIdRes\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\"#\n\x13GetWeChatIdLoginReq\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\"G\n\x13GetWeChatIdLoginRes\x12\r\n\x05token\x18\x01 \x01(\t\x12\x10\n\x08union_id\x18\x02 \x01(\t\x12\x0f\n\x07open_id\x18\x03 \x01(\t\":\n\x08UserInfo\x12\x10\n\x08nickname\x18\x01 \x01(\t\x12\x0c\n\x04icon\x18\x02 \x01(\t\x12\x0e\n\x06gender\x18\x03 \x01(\x05\"\xf0\x01\n\x16GetMiniProgramLoginReq\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\r\n\x05\x61ppid\x18\x02 \x01(\t\x12,\n\nlogin_type\x18\x03 \x01(\x0e\x32\x18.uauth_pb.UauthLoginType\x12%\n\tuser_info\x18\x04 \x01(\x0b\x32\x12.uauth_pb.UserInfo\x12\x16\n\x0e\x65ncrypted_data\x18\x05 \x01(\t\x12\n\n\x02iv\x18\x06 \x01(\t\x12/\n\x0e\x64\x65vice_message\x18\x07 \x01(\x0b\x32\x17.uauth_pb.DeviceMessage\x12\x0f\n\x07\x63ode_id\x18\x08 \x01(\t\"u\n\x13MiniProgramPhoneReq\x12\x16\n\x0e\x65ncrypted_data\x18\x01 \x01(\t\x12\n\n\x02iv\x18\x02 \x01(\t\x12,\n\nlogin_type\x18\x03 \x01(\x0e\x32\x18.uauth_pb.UauthLoginType\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\"\x15\n\x13MiniProgramPhoneRes\"]\n\x0f\x41pplyCertifyReq\x12+\n\x0c\x63\x65rtify_type\x18\x01 \x01(\x0e\x32\x15.uauth_pb.CertifyType\x12\x0f\n\x07id_card\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"b\n\x0f\x41pplyCertifyRes\x12\x0f\n\x07\x66\x61\x63\x65_id\x18\x01 \x01(\t\x12\x10\n\x08trade_no\x18\x02 \x01(\t\x12\r\n\x05nonce\x18\x03 \x01(\t\x12\x0f\n\x07user_id\x18\x04 \x01(\t\x12\x0c\n\x04sign\x18\x05 \x01(\t\"\x8a\x01\n\x13\x41pplyCertifySignReq\x12+\n\x0c\x63\x65rtify_type\x18\x01 \x01(\x0e\x32\x15.uauth_pb.CertifyType\x12\x0f\n\x07id_card\x18\x02 \x01(\t\x12\x14\n\x0cid_card_sign\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x11\n\tname_sign\x18\x05 \x01(\t\"\x12\n\x10\x43\x65rtifyResultReq\"^\n\x10\x43\x65rtifyResultRes\x12+\n\x0c\x63\x65rtify_type\x18\x01 \x01(\x0e\x32\x15.uauth_pb.CertifyType\x12\x0f\n\x07id_card\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x18\n\x16\x41\x63\x63ountPhoneSmsCodeReq\"\x18\n\x16\x41\x63\x63ountPhoneSmsCodeRes\"\xc6\x01\n\x19\x41\x63\x63ountSubsidiaryLoginReq\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x02 \x01(\x05\x12\x0f\n\x07\x63hannel\x18\x03 \x01(\x05\x12\x10\n\x08sms_code\x18\x04 \x01(\t\x12\x18\n\x10u_meng_device_id\x18\x05 \x01(\t\x12\x13\n\x0byidun_token\x18\x06 \x01(\t\x12/\n\x0e\x64\x65vice_message\x18\x07 \x01(\x0b\x32\x17.uauth_pb.DeviceMessage\"\x8a\x01\n\x10GetGuestLoginReq\x12\x11\n\tguest_key\x18\x01 \x01(\t\x12\x0c\n\x04sign\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x03 \x01(\x05\x12\x0f\n\x07\x63hannel\x18\x04 \x01(\x05\x12/\n\x0e\x64\x65vice_message\x18\x05 \x01(\x0b\x32\x17.uauth_pb.DeviceMessage\"a\n\x16\x41\x63\x63ountBindPhoneSMSReq\x12\r\n\x05phone\x18\x01 \x01(\t\x12\x10\n\x08sms_code\x18\x02 \x01(\t\x12\x12\n\nverify_old\x18\x03 \x01(\x08\x12\x12\n\nphone_sign\x18\x04 \x01(\t\"\x18\n\x16\x41\x63\x63ountBindPhoneSMSRes\"\x8d\x01\n\x13\x41\x63\x63ountBindThirdReq\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x02 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\t\x12,\n\nlogin_type\x18\x04 \x01(\x0e\x32\x18.uauth_pb.UauthLoginType\x12\x14\n\x0ctoken_secret\x18\x05 \x01(\t\"\x15\n\x13\x41\x63\x63ountBindThirdRes\"\x14\n\x12\x41\x63\x63ountBindListReq\"Z\n\x12\x41\x63\x63ountBindListRes\x12&\n\x04list\x18\x01 \x03(\x0e\x32\x18.uauth_pb.UauthLoginType\x12\r\n\x05phone\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\"`\n\x13\x42indPhoneSmsCodeReq\x12\x0f\n\x07\x63ountry\x18\x01 \x01(\x05\x12\x10\n\x08phone_no\x18\x02 \x01(\t\x12\x12\n\nverify_old\x18\x03 \x01(\x08\x12\x12\n\nphone_sign\x18\x04 \x01(\t\"\x15\n\x13\x42indPhoneSmsCodeRes\"L\n\x13\x42indEmailSesCodeReq\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x12\n\nemail_sign\x18\x02 \x01(\t\x12\x12\n\nverify_old\x18\x03 \x01(\x08\"\x15\n\x13\x42indEmailSesCodeRes\"a\n\x16\x41\x63\x63ountBindEmailSESReq\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x12\n\nemail_sign\x18\x02 \x01(\t\x12\x10\n\x08ses_code\x18\x03 \x01(\t\x12\x12\n\nverify_old\x18\x04 \x01(\x08\"\x18\n\x16\x41\x63\x63ountBindEmailSESRes\"\xe2\x01\n\x15GetAccountRegisterReq\x12\x0f\n\x07\x63ountry\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x04 \x01(\x05\x12\x10\n\x08nickname\x18\x05 \x01(\t\x12/\n\rregister_type\x18\x06 \x01(\x0e\x32\x18.uauth_pb.UauthLoginType\x12\x0c\n\x04\x63ode\x18\x07 \x01(\t\x12\x0c\n\x04sign\x18\x08 \x01(\t\x12\x12\n\nvalue_sign\x18\t \x01(\t\x12\x0f\n\x07\x63hannel\x18\n \x01(\x05\"\xb3\x01\n\x1aGetAccountPasswordLoginReq\x12\x0f\n\x07\x63ountry\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\x12,\n\nlogin_type\x18\x04 \x01(\x0e\x32\x18.uauth_pb.UauthLoginType\x12\x13\n\x0b\x64\x65vice_type\x18\x05 \x01(\x05\x12\x0c\n\x04sign\x18\x06 \x01(\t\x12\x12\n\nvalue_sign\x18\x07 \x01(\t\"2\n\rGetSesCodeReq\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x12\n\nemail_sign\x18\x02 \x01(\t\"\x0f\n\rGetSesCodeRes\"E\n\x0eGetSesTokenReq\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x12\n\nemail_sign\x18\x02 \x01(\t\x12\x10\n\x08ses_code\x18\x03 \x01(\t\"#\n\x0eGetSesTokenRes\x12\x11\n\tses_token\x18\x01 \x01(\t\"m\n\x15ResetPasswordBySesReq\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x12\n\nemail_sign\x18\x02 \x01(\t\x12\x11\n\tses_token\x18\x03 \x01(\t\x12\x10\n\x08password\x18\x04 \x01(\t\x12\x0c\n\x04sign\x18\x05 \x01(\t\"\x17\n\x15ResetPasswordBySesRes\")\n\x16RemoteLoginSendCodeReq\x12\x0f\n\x07user_id\x18\x01 \x01(\x12\"\x18\n\x16RemoteLoginSendCodeRes\":\n\x19RemoteLoginConfirmCodeReq\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\x12\"C\n\x19RemoteLoginConfirmCodeRes\x12&\n\x03res\x18\x01 \x01(\x0b\x32\x19.uauth_pb.CommonSignInRes\"T\n\x1eVerifyCancelSignInWithAppleReq\x12\x16\n\x0eidentity_token\x18\x01 \x01(\t\x12\x1a\n\x12\x61uthorization_code\x18\x02 \x01(\t\" \n\x1eVerifyCancelSignInWithAppleRes\"*\n\x18WechatCodeLoginTicketReq\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\"*\n\x18WechatCodeLoginTicketRes\x12\x0e\n\x06ticket\x18\x01 \x01(\t\"&\n\x14GetWechatMiniCodeReq\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\"5\n\x14GetWechatMiniCodeRes\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x0c\x12\x0f\n\x07\x63ode_id\x18\x02 \x01(\t\"A\n\x18GetWechatMiniCodeScanReq\x12\x0f\n\x07\x63ode_id\x18\x01 \x01(\t\x12\x14\n\x0c\x63ode_id_sign\x18\x02 \x01(\t\"}\n\x18GetWechatMiniCodeScanRes\x12\x32\n\x06status\x18\x01 \x01(\x0e\x32\".uauth_pb.WechatMiniCodeScanStatus\x12-\n\nlogin_data\x18\x02 \x01(\x0b\x32\x19.uauth_pb.CommonSignInRes\"(\n\x15RefusePhoneLicenseReq\x12\x0f\n\x07\x63ode_id\x18\x01 \x01(\t\"\x17\n\x15RefusePhoneLicenseRes\"5\n\x16WechatMiniBindPhoneReq\x12\r\n\x05\x61ppid\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\"\x18\n\x16WechatMiniBindPhoneRes\".\n\x1aThirdAccountBindWeChatInfo\x12\x10\n\x08nickname\x18\x01 \x01(\t\"*\n\x16ThirdAccountBindQqInfo\x12\x10\n\x08nickname\x18\x02 \x01(\t\"\x95\x01\n\x14ThirdAccountBindInfo\x12;\n\x0bwechat_info\x18\x01 \x01(\x0b\x32$.uauth_pb.ThirdAccountBindWeChatInfoH\x00\x12\x33\n\x07qq_info\x18\x02 \x01(\x0b\x32 .uauth_pb.ThirdAccountBindQqInfoH\x00\x42\x0b\n\tbind_info\"{\n\x18ThirdAccountBindInfoData\x12\x31\n\tbind_type\x18\x01 \x01(\x0e\x32\x1e.uauth_pb.ThirdAccountBindType\x12,\n\x04info\x18\x02 \x01(\x0b\x32\x1e.uauth_pb.ThirdAccountBindInfo\"\x19\n\x17ThirdAccountBindInfoReq\"P\n\x17ThirdAccountBindInfoRes\x12\x35\n\tinfo_data\x18\x01 \x03(\x0b\x32\".uauth_pb.ThirdAccountBindInfoData\"|\n\x13\x42indThirdAccountReq\x12\x31\n\tbind_type\x18\x01 \x01(\x0e\x32\x1e.uauth_pb.ThirdAccountBindType\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x04 \x01(\t\"\x15\n\x13\x42indThirdAccountRes\"`\n\x15UnbindThirdAccountReq\x12\x35\n\x08opt_type\x18\x01 \x01(\x0e\x32#.uauth_pb.UnbindThirdAccountOptType\x12\x10\n\x08sms_code\x18\x02 \x01(\t\"\x17\n\x15UnbindThirdAccountRes\"\xa2\x01\n\x15GetQrcodeLoginCodeReq\x12,\n\nlogin_type\x18\x01 \x01(\x0e\x32\x18.uauth_pb.UauthLoginType\x12.\n\x0b\x64\x65vice_type\x18\x02 \x01(\x0e\x32\x19.uauth_pb.UauthDeviceType\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x18\n\x10u_meng_device_id\x18\x04 \x01(\t\"+\n\x15GetQrcodeLoginCodeRes\x12\x12\n\nlogin_code\x18\x01 \x01(\t\"a\n\x12QrcodeScanLoginReq\x12\x12\n\nlogin_code\x18\x01 \x01(\t\x12\x17\n\x0flogin_device_id\x18\x02 \x01(\t\x12\x1e\n\x16login_u_meng_device_id\x18\x03 \x01(\t\"\x14\n\x12QrcodeScanLoginRes\"Z\n\x17GetQrcodeLoginStatusReq\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x18\n\x10u_meng_device_id\x18\x02 \x01(\t\x12\x12\n\nlogin_code\x18\x03 \x01(\t\"\xa8\x01\n\x17GetQrcodeLoginStatusRes\x12.\n\x06status\x18\x01 \x01(\x0e\x32\x1e.uauth_pb.GetQrcodeLoginStatus\x12\x32\n\x0f\x63ommonSignInRes\x18\x02 \x01(\x0b\x32\x19.uauth_pb.CommonSignInRes\x12\x14\n\x0cuserNickname\x18\x03 \x01(\t\x12\x13\n\x0buserIconUrl\x18\x04 \x01(\t\"\xba\x01\n\x17SetQrcodeLoginStatusReq\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x18\n\x10u_meng_device_id\x18\x02 \x01(\t\x12\x12\n\nlogin_code\x18\x03 \x01(\t\x12\x33\n\x0bloginStatus\x18\x04 \x01(\x0e\x32\x1e.uauth_pb.GetQrcodeLoginStatus\x12\x14\n\x0cuserNickname\x18\x05 \x01(\t\x12\x13\n\x0buserIconUrl\x18\x06 \x01(\t\"\x19\n\x17SetQrcodeLoginStatusRes\"x\n\x1bGetAccountRegisterStatusReq\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.uauth_pb.AccountRegisterType\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0c\n\x04sign\x18\x03 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x04 \x01(\x05\"3\n\x1bGetAccountRegisterStatusRes\x12\x14\n\x0cisRegistered\x18\x01 \x01(\x08\"2\n\x10GetUmengPhoneReq\x12\x0f\n\x07\x61pp_key\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\"!\n\x10GetUmengPhoneRes\x12\r\n\x05phone\x18\x01 \x01(\t\"I\n\x14\x41\x63\x63ountCrossTypeInfo\x12\x31\n\ncross_type\x18\x01 \x01(\x0e\x32\x1d.uauth_pb.AccountAppCrossType\"\x19\n\x17\x41\x63\x63ountCrossTypeInfoReq\"L\n\x17\x41\x63\x63ountCrossTypeInfoRes\x12\x31\n\tinfo_list\x18\x01 \x03(\x0b\x32\x1e.uauth_pb.AccountCrossTypeInfo\"\x1a\n\x18\x41pplyAccountCrossTypeReq\"\x1a\n\x18\x41pplyAccountCrossTypeRes\"H\n\x18\x43heckInAppChargeLimitReq\x12,\n\x0b\x63harge_type\x18\x01 \x01(\x0e\x32\x17.uauth_pb.AppChargeType\".\n\x18\x43heckInAppChargeLimitRes\x12\x12\n\ncan_charge\x18\x01 \x01(\x08\"\x98\x02\n\x15GetAlipayMiniOrderReq\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\x12\x12\n\naccount_id\x18\x02 \x01(\x03\x12+\n\x08pay_type\x18\x03 \x01(\x0e\x32\x19.uauth_pb.UPayChannelType\x12\x0c\n\x04gold\x18\x04 \x01(\x03\x12\x0b\n\x03num\x18\x05 \x01(\x05\x12\x10\n\x08store_id\x18\x06 \x01(\x05\x12\x12\n\nreturn_url\x18\x07 \x01(\t\x12=\n\x07\x65xtends\x18\x08 \x03(\x0b\x32,.uauth_pb.GetAlipayMiniOrderReq.ExtendsEntry\x1a.\n\x0c\x45xtendsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\")\n\x15GetAlipayMiniOrderRes\x12\x10\n\x08trade_no\x18\x01 \x01(\t\"!\n\x0fGetGoodsListReq\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\">\n\x0fGetGoodsListRes\x12+\n\x04list\x18\x01 \x03(\x0b\x32\x1d.uauth_pb.AlipayMiniIndexItem\"\xb6\x01\n\x13\x41lipayMiniIndexItem\x12\x30\n\tdata_type\x18\x01 \x01(\x0e\x32\x1d.uauth_pb.AlipayMiniIndexType\x12\x31\n\x06\x62\x61nner\x18\x02 \x01(\x0b\x32\x1f.uauth_pb.AlipayMiniIndexBannerH\x00\x12\x32\n\x04list\x18\x03 \x01(\x0b\x32\".uauth_pb.AlipayMiniIndexGoodsListH\x00\x42\x06\n\x04\x64\x61ta\"+\n\x15\x41lipayMiniIndexBanner\x12\x12\n\nbanner_url\x18\x01 \x01(\t\"R\n\x18\x41lipayMiniIndexGoodsList\x12\x36\n\ngoods_list\x18\x01 \x03(\x0b\x32\".uauth_pb.AlipayMiniIndexGoodsItem\"\xad\x01\n\x18\x41lipayMiniIndexGoodsItem\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07img_url\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\r\n\x05price\x18\x05 \x01(\t\x12\x31\n\ngoods_type\x18\x06 \x01(\x0e\x32\x1d.uauth_pb.AlipayMiniGoodsType\x12\x0e\n\x04gold\x18\x07 \x01(\x03H\x00\x42\x06\n\x04\x64\x61ta*\x86\x07\n\x0e\x45rrorUAuthCode\x12\x13\n\x0f\x45rrorUAuth_Zero\x10\x00\x12\x1d\n\x17\x45rrorUAuthRegisterParam\x10\xd9\xb0\x02\x12\x1c\n\x16\x45rrorUAuthAccountExist\x10\xda\xb0\x02\x12\x1e\n\x18\x45rrorUAuthSessionTimeOut\x10\xdb\xb0\x02\x12\x1f\n\x19\x45rrorUAuthSessionNotFound\x10\xdc\xb0\x02\x12\x1c\n\x16\x45rrorUAuthUserNotFound\x10\xdd\xb0\x02\x12\x1f\n\x19\x45rrorUAuthAccountNotExist\x10\xde\xb0\x02\x12!\n\x1b\x45rrorUAuthPassWordNoCorrect\x10\xdf\xb0\x02\x12\x1d\n\x17\x45rrorUAuthCodeIncorrect\x10\xe0\xb0\x02\x12\x1d\n\x17\x45rrorUAuthPhoneNotExist\x10\xe1\xb0\x02\x12\x1b\n\x15\x45rrorUAuthUserNoRight\x10\xe2\xb0\x02\x12\x1a\n\x14\x45rrorUAuthInvalidWay\x10\xe3\xb0\x02\x12\x19\n\x13\x45rrorUAuthNeedLogin\x10\xe4\xb0\x02\x12\x18\n\x12\x45rrorUAuthGetToken\x10\xe5\xb0\x02\x12\x1b\n\x15\x45rrorUAuthAccessToken\x10\xe6\xb0\x02\x12\x1d\n\x17\x45rrorUAuthWrongPhoneNum\x10\xe7\xb0\x02\x12\x1d\n\x17\x45rrorUAuthServerOffLine\x10\xe8\xb0\x02\x12!\n\x1b\x45rrorUAuthPhoneAlreadyExist\x10\xe9\xb0\x02\x12\x18\n\x12\x45rrorIAPHasNoOrder\x10\xaa\xcb\x0e\x12\x18\n\x12\x45rrorCheckIAPOrder\x10\xab\xcb\x0e\x12\x1b\n\x15\x45rrorCheckIAPBundleID\x10\xac\xcb\x0e\x12\x16\n\x10\x45rrorTooFrequent\x10\xb6\xcb\x0e\x12\x0e\n\x08\x45rror3rd\x10\xb7\xcb\x0e\x12\x1a\n\x14\x45rrorPasswordInvalid\x10\xb8\xcb\x0e\x12\x1b\n\x15\x45rrorWrongOldPassword\x10\xb9\xcb\x0e\x12\x15\n\x0f\x45rrorLoginBlack\x10\xba\xcb\x0e\x12\x15\n\x0f\x45rrorHasAccount\x10\xbb\xcb\x0e\x12\x1c\n\x16\x45rrorUAuthPswNoCorrect\x10\xbc\xcb\x0e\x12\x1e\n\x18\x45rrorUAuthPhoneNoCorrect\x10\xbd\xcb\x0e\x12\x19\n\x13\x45rrorUserLimitLogin\x10\xd2\xcb\x0e\x12\x1c\n\x16\x45rrorRefusePhoneLicens\x10\xd4\xcb\x0e*I\n\rIAPStatusType\x12\x0c\n\x08IAP_NONE\x10\x00\x12\x13\n\x0fIAP_STATUS_FAIL\x10\x01\x12\x15\n\x11IAP_STATUS_CANCEL\x10\x02*=\n\x0c\x43hargeStatus\x12\x0f\n\x0b\x43S_CHARGING\x10\x00\x12\r\n\tCS_FINISH\x10\x01\x12\r\n\tCS_REFUND\x10\x02*9\n\x0eReportDataType\x12\x0c\n\x08RDT_Null\x10\x00\x12\x19\n\x15RDT_CMB_VIP_Expedited\x10\x01*R\n\nVerifyType\x12\x0b\n\x07VT_NULL\x10\x00\x12\x12\n\x0eVT_RemoteLogin\x10\x01\x12\x0e\n\nVT_Protect\x10\x02\x12\x13\n\x0fVT_AnomalyLogin\x10\x03*k\n\nSMSCodeTpl\x12\x13\n\x0fSMSCodeTpl_Zero\x10\x00\x12\x14\n\x10SMSCodeTpl_Login\x10\x01\x12\x17\n\x13SMSCodeTpl_ResetPwd\x10\x02\x12\x19\n\x15SMSCodeTpl_VerifyCode\x10\x03*)\n\x0b\x43\x65rtifyType\x12\x0b\n\x07\x43T_None\x10\x00\x12\r\n\tCT_IdCard\x10\x01*\x82\x01\n\x18WechatMiniCodeScanStatus\x12\x10\n\x0cWMCSS_NoScan\x10\x00\x12\x11\n\rWMCSS_Timeout\x10\x01\x12\x10\n\x0cWMCSS_ScanIn\x10\x02\x12\x11\n\rWMCSS_ScanEnd\x10\x03\x12\x1c\n\x18WMCSS_RefusePhoneLicense\x10\x04*C\n\x14ThirdAccountBindType\x12\r\n\tTABT_NONE\x10\x00\x12\x0f\n\x0bTABT_WEIXIN\x10\x01\x12\x0b\n\x07TABT_QQ\x10\x02*=\n\x19UnbindThirdAccountOptType\x12\x0e\n\nUTAOT_Send\x10\x00\x12\x10\n\x0cUTAOT_Verify\x10\x01*S\n\x14GetQrcodeLoginStatus\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0b\n\x07SUCCESS\x10\x02\x12\x0b\n\x07\x45XPIRED\x10\x03\x12\n\n\x06\x43\x41NCEL\x10\x04*>\n\x13\x41\x63\x63ountRegisterType\x12\x0b\n\x07RT_NONE\x10\x00\x12\x0c\n\x08RT_PHONE\x10\x01\x12\x0c\n\x08RT_EMAIL\x10\x02*3\n\x13\x41\x63\x63ountAppCrossType\x12\r\n\tAACT_None\x10\x00\x12\r\n\tAACT_Neon\x10\x01*<\n\rAppChargeType\x12\x0c\n\x08\x41\x43T_None\x10\x00\x12\r\n\tACT_Apple\x10\x01\x12\x0e\n\nACT_Google\x10\x02*E\n\x13\x41lipayMiniIndexType\x12\r\n\tAMIT_NONE\x10\x00\x12\x0f\n\x0b\x41MIT_BANNER\x10\x01\x12\x0e\n\nAMIT_GOODS\x10\x02*3\n\x13\x41lipayMiniGoodsType\x12\r\n\tAMGT_NONE\x10\x00\x12\r\n\tAMGT_GOLD\x10\x01\x32\x9a/\n\x0bUauthExtObj\x12;\n\tVerifyIAP\x12\x16.uauth_pb.VerifyIAPReq\x1a\x16.uauth_pb.VerifyIAPRes\x12\x41\n\x0bGetGoodList\x12\x18.uauth_pb.GetGoodListReq\x1a\x18.uauth_pb.GetGoodListRes\x12\x38\n\x08OrderIAP\x12\x15.uauth_pb.OrderIAPReq\x1a\x15.uauth_pb.OrderIAPRes\x12G\n\rCloseOrderIAP\x12\x1a.uauth_pb.CloseOrderIAPReq\x1a\x1a.uauth_pb.CloseOrderIAPRes\x12_\n\x17GetVIPChargeAccountInfo\x12!.uauth_pb.VIPChargeAccountInfoReq\x1a!.uauth_pb.VIPChargeAccountInfoRes\x12\x44\n\x0cVIPChargeLog\x12\x19.uauth_pb.VIPChargeLogReq\x1a\x19.uauth_pb.VIPChargeLogRes\x12>\n\nReportData\x12\x17.uauth_pb.ReportDataReq\x1a\x17.uauth_pb.ReportDataRes\x12;\n\tGetCharge\x12\x16.uauth_pb.GetChargeReq\x1a\x16.uauth_pb.GetChargeRes\x12M\n\x12GetSignInWithApple\x12\x1c.uauth_pb.SignInWithAppleReq\x1a\x19.uauth_pb.CommonSignInRes\x12>\n\nGetSmsCode\x12\x17.uauth_pb.GetSmsCodeReq\x1a\x17.uauth_pb.GetSmsCodeRes\x12\x44\n\x10GetSmsCodeBySign\x12\x17.uauth_pb.GetSmsCodeReq\x1a\x17.uauth_pb.GetSmsCodeRes\x12\x41\n\x0bGetSmsToken\x12\x18.uauth_pb.GetSmsTokenReq\x1a\x18.uauth_pb.GetSmsTokenRes\x12G\n\x11GetSmsTokenBySign\x12\x18.uauth_pb.GetSmsTokenReq\x1a\x18.uauth_pb.GetSmsTokenRes\x12?\n\x0bGetDevLogin\x12\x15.uauth_pb.DevLoginReq\x1a\x19.uauth_pb.CommonSignInRes\x12K\n\x11GetIdOrPhoneLogin\x12\x1b.uauth_pb.IdOrPhoneLoginReq\x1a\x19.uauth_pb.CommonSignInRes\x12\x43\n\rGetThirdLogin\x12\x17.uauth_pb.ThirdLoginReq\x1a\x19.uauth_pb.CommonSignInRes\x12Q\n\x14GetLoginWithPhoneSMS\x12\x1e.uauth_pb.LoginWithPhoneSMSReq\x1a\x19.uauth_pb.CommonSignInRes\x12W\n\x1aGetLoginWithPhoneSMSBySign\x12\x1e.uauth_pb.LoginWithPhoneSMSReq\x1a\x19.uauth_pb.CommonSignInRes\x12Y\n\x18GetChinaMobileQuickLogin\x12\".uauth_pb.ChinaMobileQuickLoginReq\x1a\x19.uauth_pb.CommonSignInRes\x12O\n\x13GetChinaTelecomAuth\x12\x1d.uauth_pb.ChinaTelecomAuthReq\x1a\x19.uauth_pb.CommonSignInRes\x12M\n\x12GetUmengQuickLogin\x12\x1c.uauth_pb.UmengQuickLoginReq\x1a\x19.uauth_pb.CommonSignInRes\x12J\n\x10GetResetPassword\x12\x1a.uauth_pb.ResetPasswordReq\x1a\x1a.uauth_pb.ResetPasswordRes\x12P\n\x16GetResetPasswordBySign\x12\x1a.uauth_pb.ResetPasswordReq\x1a\x1a.uauth_pb.ResetPasswordRes\x12\x44\n\x0cUpdatePasswd\x12\x19.uauth_pb.UpdatePasswdReq\x1a\x19.uauth_pb.UpdatePasswdRes\x12\x35\n\tGetInvite\x12\x13.uauth_pb.InviteReq\x1a\x13.uauth_pb.InviteRes\x12\x41\n\x0bGetSyncTime\x12\x18.uauth_pb.GetSyncTimeReq\x1a\x18.uauth_pb.GetSyncTimeRes\x12S\n\x11ReportBuyNobility\x12\x1e.uauth_pb.ReportBuyNobilityReq\x1a\x1e.uauth_pb.ReportBuyNobilityRes\x12J\n\x0eGetWeChatAppId\x12\x1b.uauth_pb.GetWeChatAppIdReq\x1a\x1b.uauth_pb.GetWeChatAppIdRes\x12P\n\x10GetWeChatIdLogin\x12\x1d.uauth_pb.GetWeChatIdLoginReq\x1a\x1d.uauth_pb.GetWeChatIdLoginRes\x12\x61\n\x15GoogleIABProductItems\x12\".uauth_pb.GoogleIABProductItemsReq\x1a\".uauth_pb.GoogleIABProductItemsRes\"\x00\x12O\n\x0fGoogleIABNotify\x12\x1c.uauth_pb.GoogleIABNotifyReq\x1a\x1c.uauth_pb.GoogleIABNotifyRes\"\x00\x12R\n\x13GetMiniProgramLogin\x12 .uauth_pb.GetMiniProgramLoginReq\x1a\x19.uauth_pb.CommonSignInRes\x12P\n\x10MiniProgramPhone\x12\x1d.uauth_pb.MiniProgramPhoneReq\x1a\x1d.uauth_pb.MiniProgramPhoneRes\x12\x44\n\x0c\x41pplyCertify\x12\x19.uauth_pb.ApplyCertifyReq\x1a\x19.uauth_pb.ApplyCertifyRes\x12L\n\x10\x41pplyCertifySign\x12\x1d.uauth_pb.ApplyCertifySignReq\x1a\x19.uauth_pb.ApplyCertifyRes\x12G\n\rCertifyResult\x12\x1a.uauth_pb.CertifyResultReq\x1a\x1a.uauth_pb.CertifyResultRes\x12Y\n\x13\x41\x63\x63ountPhoneSmsCode\x12 .uauth_pb.AccountPhoneSmsCodeReq\x1a .uauth_pb.AccountPhoneSmsCodeRes\x12X\n\x16\x41\x63\x63ountSubsidiaryLogin\x12#.uauth_pb.AccountSubsidiaryLoginReq\x1a\x19.uauth_pb.CommonSignInRes\x12\x46\n\rGetGuestLogin\x12\x1a.uauth_pb.GetGuestLoginReq\x1a\x19.uauth_pb.CommonSignInRes\x12P\n\x10\x42indPhoneSmsCode\x12\x1d.uauth_pb.BindPhoneSmsCodeReq\x1a\x1d.uauth_pb.BindPhoneSmsCodeRes\x12Y\n\x13\x41\x63\x63ountBindPhoneSMS\x12 .uauth_pb.AccountBindPhoneSMSReq\x1a .uauth_pb.AccountBindPhoneSMSRes\x12P\n\x10\x41\x63\x63ountBindThird\x12\x1d.uauth_pb.AccountBindThirdReq\x1a\x1d.uauth_pb.AccountBindThirdRes\x12M\n\x0f\x41\x63\x63ountBindList\x12\x1c.uauth_pb.AccountBindListReq\x1a\x1c.uauth_pb.AccountBindListRes\x12P\n\x10\x42indEmailSesCode\x12\x1d.uauth_pb.BindEmailSesCodeReq\x1a\x1d.uauth_pb.BindEmailSesCodeRes\x12Y\n\x13\x41\x63\x63ountBindEmailSES\x12 .uauth_pb.AccountBindEmailSESReq\x1a .uauth_pb.AccountBindEmailSESRes\x12P\n\x12GetAccountRegister\x12\x1f.uauth_pb.GetAccountRegisterReq\x1a\x19.uauth_pb.CommonSignInRes\x12Z\n\x17GetAccountPasswordLogin\x12$.uauth_pb.GetAccountPasswordLoginReq\x1a\x19.uauth_pb.CommonSignInRes\x12>\n\nGetSesCode\x12\x17.uauth_pb.GetSesCodeReq\x1a\x17.uauth_pb.GetSesCodeRes\x12\x41\n\x0bGetSesToken\x12\x18.uauth_pb.GetSesTokenReq\x1a\x18.uauth_pb.GetSesTokenRes\x12Y\n\x15GetResetPasswordBySes\x12\x1f.uauth_pb.ResetPasswordBySesReq\x1a\x1f.uauth_pb.ResetPasswordBySesRes\x12\\\n\x16GetRemoteLoginSendCode\x12 .uauth_pb.RemoteLoginSendCodeReq\x1a .uauth_pb.RemoteLoginSendCodeRes\x12\x65\n\x19GetRemoteLoginConfirmCode\x12#.uauth_pb.RemoteLoginConfirmCodeReq\x1a#.uauth_pb.RemoteLoginConfirmCodeRes\x12q\n\x1bVerifyCancelSignInWithApple\x12(.uauth_pb.VerifyCancelSignInWithAppleReq\x1a(.uauth_pb.VerifyCancelSignInWithAppleRes\x12\x44\n\x0cPhoneSmsCode\x12\x19.uauth_pb.PhoneSmsCodeReq\x1a\x19.uauth_pb.PhoneSmsCodeRes\x12S\n\x11\x43heckPhoneSmsCode\x12\x1e.uauth_pb.CheckPhoneSmsCodeReq\x1a\x1e.uauth_pb.CheckPhoneSmsCodeRes\x12\x62\n\x18GetWechatCodeLoginTicket\x12\".uauth_pb.WechatCodeLoginTicketReq\x1a\".uauth_pb.WechatCodeLoginTicketRes\x12S\n\x11GetWechatMiniCode\x12\x1e.uauth_pb.GetWechatMiniCodeReq\x1a\x1e.uauth_pb.GetWechatMiniCodeRes\x12_\n\x15GetWechatMiniCodeScan\x12\".uauth_pb.GetWechatMiniCodeScanReq\x1a\".uauth_pb.GetWechatMiniCodeScanRes\x12Y\n\x15GetRefusePhoneLicense\x12\x1f.uauth_pb.RefusePhoneLicenseReq\x1a\x1f.uauth_pb.RefusePhoneLicenseRes\x12Y\n\x13WechatMiniBindPhone\x12 .uauth_pb.WechatMiniBindPhoneReq\x1a .uauth_pb.WechatMiniBindPhoneRes\x12\\\n\x14ThirdAccountBindInfo\x12!.uauth_pb.ThirdAccountBindInfoReq\x1a!.uauth_pb.ThirdAccountBindInfoRes\x12P\n\x10\x42indThirdAccount\x12\x1d.uauth_pb.BindThirdAccountReq\x1a\x1d.uauth_pb.BindThirdAccountRes\x12V\n\x12UnbindThirdAccount\x12\x1f.uauth_pb.UnbindThirdAccountReq\x1a\x1f.uauth_pb.UnbindThirdAccountRes\x12V\n\x12GetQrcodeLoginCode\x12\x1f.uauth_pb.GetQrcodeLoginCodeReq\x1a\x1f.uauth_pb.GetQrcodeLoginCodeRes\x12\\\n\x14GetQrcodeLoginStatus\x12!.uauth_pb.GetQrcodeLoginStatusReq\x1a!.uauth_pb.GetQrcodeLoginStatusRes\x12\\\n\x14SetQrcodeLoginStatus\x12!.uauth_pb.SetQrcodeLoginStatusReq\x1a!.uauth_pb.SetQrcodeLoginStatusRes\x12M\n\x0fQrcodeScanLogin\x12\x1c.uauth_pb.QrcodeScanLoginReq\x1a\x1c.uauth_pb.QrcodeScanLoginRes\x12h\n\x18GetAccountRegisterStatus\x12%.uauth_pb.GetAccountRegisterStatusReq\x1a%.uauth_pb.GetAccountRegisterStatusRes\x12G\n\rGetUmengPhone\x12\x1a.uauth_pb.GetUmengPhoneReq\x1a\x1a.uauth_pb.GetUmengPhoneRes\x12\\\n\x14\x41\x63\x63ountCrossTypeInfo\x12!.uauth_pb.AccountCrossTypeInfoReq\x1a!.uauth_pb.AccountCrossTypeInfoRes\x12_\n\x15\x41pplyAccountCrossType\x12\".uauth_pb.ApplyAccountCrossTypeReq\x1a\".uauth_pb.ApplyAccountCrossTypeRes\x12_\n\x15\x43heckInAppChargeLimit\x12\".uauth_pb.CheckInAppChargeLimitReq\x1a\".uauth_pb.CheckInAppChargeLimitRes\x12V\n\x12GetAlipayMiniOrder\x12\x1f.uauth_pb.GetAlipayMiniOrderReq\x1a\x1f.uauth_pb.GetAlipayMiniOrderRes\x12\x44\n\x0cGetGoodsList\x12\x19.uauth_pb.GetGoodsListReq\x1a\x19.uauth_pb.GetGoodsListResB\x08\xa2\x02\x05PROTOb\x06proto3')

_ERRORUAUTHCODE = DESCRIPTOR.enum_types_by_name['ErrorUAuthCode']
ErrorUAuthCode = enum_type_wrapper.EnumTypeWrapper(_ERRORUAUTHCODE)
_IAPSTATUSTYPE = DESCRIPTOR.enum_types_by_name['IAPStatusType']
IAPStatusType = enum_type_wrapper.EnumTypeWrapper(_IAPSTATUSTYPE)
_CHARGESTATUS = DESCRIPTOR.enum_types_by_name['ChargeStatus']
ChargeStatus = enum_type_wrapper.EnumTypeWrapper(_CHARGESTATUS)
_REPORTDATATYPE = DESCRIPTOR.enum_types_by_name['ReportDataType']
ReportDataType = enum_type_wrapper.EnumTypeWrapper(_REPORTDATATYPE)
_VERIFYTYPE = DESCRIPTOR.enum_types_by_name['VerifyType']
VerifyType = enum_type_wrapper.EnumTypeWrapper(_VERIFYTYPE)
_SMSCODETPL = DESCRIPTOR.enum_types_by_name['SMSCodeTpl']
SMSCodeTpl = enum_type_wrapper.EnumTypeWrapper(_SMSCODETPL)
_CERTIFYTYPE = DESCRIPTOR.enum_types_by_name['CertifyType']
CertifyType = enum_type_wrapper.EnumTypeWrapper(_CERTIFYTYPE)
_WECHATMINICODESCANSTATUS = DESCRIPTOR.enum_types_by_name['WechatMiniCodeScanStatus']
WechatMiniCodeScanStatus = enum_type_wrapper.EnumTypeWrapper(_WECHATMINICODESCANSTATUS)
_THIRDACCOUNTBINDTYPE = DESCRIPTOR.enum_types_by_name['ThirdAccountBindType']
ThirdAccountBindType = enum_type_wrapper.EnumTypeWrapper(_THIRDACCOUNTBINDTYPE)
_UNBINDTHIRDACCOUNTOPTTYPE = DESCRIPTOR.enum_types_by_name['UnbindThirdAccountOptType']
UnbindThirdAccountOptType = enum_type_wrapper.EnumTypeWrapper(_UNBINDTHIRDACCOUNTOPTTYPE)
_GETQRCODELOGINSTATUS = DESCRIPTOR.enum_types_by_name['GetQrcodeLoginStatus']
GetQrcodeLoginStatus = enum_type_wrapper.EnumTypeWrapper(_GETQRCODELOGINSTATUS)
_ACCOUNTREGISTERTYPE = DESCRIPTOR.enum_types_by_name['AccountRegisterType']
AccountRegisterType = enum_type_wrapper.EnumTypeWrapper(_ACCOUNTREGISTERTYPE)
_ACCOUNTAPPCROSSTYPE = DESCRIPTOR.enum_types_by_name['AccountAppCrossType']
AccountAppCrossType = enum_type_wrapper.EnumTypeWrapper(_ACCOUNTAPPCROSSTYPE)
_APPCHARGETYPE = DESCRIPTOR.enum_types_by_name['AppChargeType']
AppChargeType = enum_type_wrapper.EnumTypeWrapper(_APPCHARGETYPE)
_ALIPAYMINIINDEXTYPE = DESCRIPTOR.enum_types_by_name['AlipayMiniIndexType']
AlipayMiniIndexType = enum_type_wrapper.EnumTypeWrapper(_ALIPAYMINIINDEXTYPE)
_ALIPAYMINIGOODSTYPE = DESCRIPTOR.enum_types_by_name['AlipayMiniGoodsType']
AlipayMiniGoodsType = enum_type_wrapper.EnumTypeWrapper(_ALIPAYMINIGOODSTYPE)
ErrorUAuth_Zero = 0
ErrorUAuthRegisterParam = 39001
ErrorUAuthAccountExist = 39002
ErrorUAuthSessionTimeOut = 39003
ErrorUAuthSessionNotFound = 39004
ErrorUAuthUserNotFound = 39005
ErrorUAuthAccountNotExist = 39006
ErrorUAuthPassWordNoCorrect = 39007
ErrorUAuthCodeIncorrect = 39008
ErrorUAuthPhoneNotExist = 39009
ErrorUAuthUserNoRight = 39010
ErrorUAuthInvalidWay = 39011
ErrorUAuthNeedLogin = 39012
ErrorUAuthGetToken = 39013
ErrorUAuthAccessToken = 39014
ErrorUAuthWrongPhoneNum = 39015
ErrorUAuthServerOffLine = 39016
ErrorUAuthPhoneAlreadyExist = 39017
ErrorIAPHasNoOrder = 239018
ErrorCheckIAPOrder = 239019
ErrorCheckIAPBundleID = 239020
ErrorTooFrequent = 239030
Error3rd = 239031
ErrorPasswordInvalid = 239032
ErrorWrongOldPassword = 239033
ErrorLoginBlack = 239034
ErrorHasAccount = 239035
ErrorUAuthPswNoCorrect = 239036
ErrorUAuthPhoneNoCorrect = 239037
ErrorUserLimitLogin = 239058
ErrorRefusePhoneLicens = 239060
IAP_NONE = 0
IAP_STATUS_FAIL = 1
IAP_STATUS_CANCEL = 2
CS_CHARGING = 0
CS_FINISH = 1
CS_REFUND = 2
RDT_Null = 0
RDT_CMB_VIP_Expedited = 1
VT_NULL = 0
VT_RemoteLogin = 1
VT_Protect = 2
VT_AnomalyLogin = 3
SMSCodeTpl_Zero = 0
SMSCodeTpl_Login = 1
SMSCodeTpl_ResetPwd = 2
SMSCodeTpl_VerifyCode = 3
CT_None = 0
CT_IdCard = 1
WMCSS_NoScan = 0
WMCSS_Timeout = 1
WMCSS_ScanIn = 2
WMCSS_ScanEnd = 3
WMCSS_RefusePhoneLicense = 4
TABT_NONE = 0
TABT_WEIXIN = 1
TABT_QQ = 2
UTAOT_Send = 0
UTAOT_Verify = 1
NONE = 0
PENDING = 1
SUCCESS = 2
EXPIRED = 3
CANCEL = 4
RT_NONE = 0
RT_PHONE = 1
RT_EMAIL = 2
AACT_None = 0
AACT_Neon = 1
ACT_None = 0
ACT_Apple = 1
ACT_Google = 2
AMIT_NONE = 0
AMIT_BANNER = 1
AMIT_GOODS = 2
AMGT_NONE = 0
AMGT_GOLD = 1


_VERIFYIAPREQ = DESCRIPTOR.message_types_by_name['VerifyIAPReq']
_VERIFYIAPRES = DESCRIPTOR.message_types_by_name['VerifyIAPRes']
_GOLDCARD = DESCRIPTOR.message_types_by_name['GoldCard']
_GETGOODLISTREQ = DESCRIPTOR.message_types_by_name['GetGoodListReq']
_GETGOODLISTRES = DESCRIPTOR.message_types_by_name['GetGoodListRes']
_ORDERIAPREQ = DESCRIPTOR.message_types_by_name['OrderIAPReq']
_ORDERIAPRES = DESCRIPTOR.message_types_by_name['OrderIAPRes']
_CLOSEORDERIAPREQ = DESCRIPTOR.message_types_by_name['CloseOrderIAPReq']
_CLOSEORDERIAPRES = DESCRIPTOR.message_types_by_name['CloseOrderIAPRes']
_VIPCHARGEACCOUNTINFOREQ = DESCRIPTOR.message_types_by_name['VIPChargeAccountInfoReq']
_VIPCHARGEACCOUNTINFORES = DESCRIPTOR.message_types_by_name['VIPChargeAccountInfoRes']
_VIPCHARGELOGREQ = DESCRIPTOR.message_types_by_name['VIPChargeLogReq']
_VIPCHARGELOGRES = DESCRIPTOR.message_types_by_name['VIPChargeLogRes']
_VIPCHARGELOGS = DESCRIPTOR.message_types_by_name['VIPChargeLogs']
_VIPCHARGEITEM = DESCRIPTOR.message_types_by_name['VIPChargeItem']
_REPORTDATAREQ = DESCRIPTOR.message_types_by_name['ReportDataReq']
_REPORTDATARES = DESCRIPTOR.message_types_by_name['ReportDataRes']
_GETCHARGEREQ = DESCRIPTOR.message_types_by_name['GetChargeReq']
_GETCHARGEREQ_EXTENDSENTRY = _GETCHARGEREQ.nested_types_by_name['ExtendsEntry']
_GETCHARGEREQ_EXTRADATAENTRY = _GETCHARGEREQ.nested_types_by_name['ExtraDataEntry']
_GETCHARGERES = DESCRIPTOR.message_types_by_name['GetChargeRes']
_GETSMSCODEREQ = DESCRIPTOR.message_types_by_name['GetSmsCodeReq']
_GETSMSCODERES = DESCRIPTOR.message_types_by_name['GetSmsCodeRes']
_GETSMSTOKENREQ = DESCRIPTOR.message_types_by_name['GetSmsTokenReq']
_GETSMSTOKENRES = DESCRIPTOR.message_types_by_name['GetSmsTokenRes']
_PHONESMSCODEREQ = DESCRIPTOR.message_types_by_name['PhoneSmsCodeReq']
_PHONESMSCODERES = DESCRIPTOR.message_types_by_name['PhoneSmsCodeRes']
_CHECKPHONESMSCODEREQ = DESCRIPTOR.message_types_by_name['CheckPhoneSmsCodeReq']
_CHECKPHONESMSCODERES = DESCRIPTOR.message_types_by_name['CheckPhoneSmsCodeRes']
_COMMONSIGNINRES = DESCRIPTOR.message_types_by_name['CommonSignInRes']
_COMMONSIGNINRES_EXTENDSENTRY = _COMMONSIGNINRES.nested_types_by_name['ExtendsEntry']
_SIGNINWITHAPPLEREQ = DESCRIPTOR.message_types_by_name['SignInWithAppleReq']
_IDORPHONELOGINREQ = DESCRIPTOR.message_types_by_name['IdOrPhoneLoginReq']
_LOGINWITHPHONESMSREQ = DESCRIPTOR.message_types_by_name['LoginWithPhoneSMSReq']
_THIRDLOGINREQ = DESCRIPTOR.message_types_by_name['ThirdLoginReq']
_CHINAMOBILEQUICKLOGINREQ = DESCRIPTOR.message_types_by_name['ChinaMobileQuickLoginReq']
_CHINATELECOMAUTHREQ = DESCRIPTOR.message_types_by_name['ChinaTelecomAuthReq']
_UMENGQUICKLOGINREQ = DESCRIPTOR.message_types_by_name['UmengQuickLoginReq']
_DEVLOGINREQ = DESCRIPTOR.message_types_by_name['DevLoginReq']
_RESETPASSWORDREQ = DESCRIPTOR.message_types_by_name['ResetPasswordReq']
_RESETPASSWORDRES = DESCRIPTOR.message_types_by_name['ResetPasswordRes']
_LOGINSECRETREQ = DESCRIPTOR.message_types_by_name['LoginSecretReq']
_LOGINSECRETRES = DESCRIPTOR.message_types_by_name['LoginSecretRes']
_UPDATEPASSWDREQ = DESCRIPTOR.message_types_by_name['UpdatePasswdReq']
_UPDATEPASSWDRES = DESCRIPTOR.message_types_by_name['UpdatePasswdRes']
_INVITEREQ = DESCRIPTOR.message_types_by_name['InviteReq']
_INVITERES = DESCRIPTOR.message_types_by_name['InviteRes']
_GETSYNCTIMEREQ = DESCRIPTOR.message_types_by_name['GetSyncTimeReq']
_GETSYNCTIMERES = DESCRIPTOR.message_types_by_name['GetSyncTimeRes']
_REPORTBUYNOBILITYREQ = DESCRIPTOR.message_types_by_name['ReportBuyNobilityReq']
_REPORTBUYNOBILITYRES = DESCRIPTOR.message_types_by_name['ReportBuyNobilityRes']
_GOOGLEIABNOTIFYREQ = DESCRIPTOR.message_types_by_name['GoogleIABNotifyReq']
_GOOGLEIABNOTIFYREQ_BUYINTENT = _GOOGLEIABNOTIFYREQ.nested_types_by_name['BuyIntent']
_GOOGLEIABNOTIFYRES = DESCRIPTOR.message_types_by_name['GoogleIABNotifyRes']
_GOOGLEIABPRODUCTITEM = DESCRIPTOR.message_types_by_name['GoogleIABProductItem']
_GOOGLEIABPRODUCTITEMSREQ = DESCRIPTOR.message_types_by_name['GoogleIABProductItemsReq']
_GOOGLEIABPRODUCTITEMSRES = DESCRIPTOR.message_types_by_name['GoogleIABProductItemsRes']
_GETWECHATAPPIDREQ = DESCRIPTOR.message_types_by_name['GetWeChatAppIdReq']
_GETWECHATAPPIDRES = DESCRIPTOR.message_types_by_name['GetWeChatAppIdRes']
_GETWECHATIDLOGINREQ = DESCRIPTOR.message_types_by_name['GetWeChatIdLoginReq']
_GETWECHATIDLOGINRES = DESCRIPTOR.message_types_by_name['GetWeChatIdLoginRes']
_USERINFO = DESCRIPTOR.message_types_by_name['UserInfo']
_GETMINIPROGRAMLOGINREQ = DESCRIPTOR.message_types_by_name['GetMiniProgramLoginReq']
_MINIPROGRAMPHONEREQ = DESCRIPTOR.message_types_by_name['MiniProgramPhoneReq']
_MINIPROGRAMPHONERES = DESCRIPTOR.message_types_by_name['MiniProgramPhoneRes']
_APPLYCERTIFYREQ = DESCRIPTOR.message_types_by_name['ApplyCertifyReq']
_APPLYCERTIFYRES = DESCRIPTOR.message_types_by_name['ApplyCertifyRes']
_APPLYCERTIFYSIGNREQ = DESCRIPTOR.message_types_by_name['ApplyCertifySignReq']
_CERTIFYRESULTREQ = DESCRIPTOR.message_types_by_name['CertifyResultReq']
_CERTIFYRESULTRES = DESCRIPTOR.message_types_by_name['CertifyResultRes']
_ACCOUNTPHONESMSCODEREQ = DESCRIPTOR.message_types_by_name['AccountPhoneSmsCodeReq']
_ACCOUNTPHONESMSCODERES = DESCRIPTOR.message_types_by_name['AccountPhoneSmsCodeRes']
_ACCOUNTSUBSIDIARYLOGINREQ = DESCRIPTOR.message_types_by_name['AccountSubsidiaryLoginReq']
_GETGUESTLOGINREQ = DESCRIPTOR.message_types_by_name['GetGuestLoginReq']
_ACCOUNTBINDPHONESMSREQ = DESCRIPTOR.message_types_by_name['AccountBindPhoneSMSReq']
_ACCOUNTBINDPHONESMSRES = DESCRIPTOR.message_types_by_name['AccountBindPhoneSMSRes']
_ACCOUNTBINDTHIRDREQ = DESCRIPTOR.message_types_by_name['AccountBindThirdReq']
_ACCOUNTBINDTHIRDRES = DESCRIPTOR.message_types_by_name['AccountBindThirdRes']
_ACCOUNTBINDLISTREQ = DESCRIPTOR.message_types_by_name['AccountBindListReq']
_ACCOUNTBINDLISTRES = DESCRIPTOR.message_types_by_name['AccountBindListRes']
_BINDPHONESMSCODEREQ = DESCRIPTOR.message_types_by_name['BindPhoneSmsCodeReq']
_BINDPHONESMSCODERES = DESCRIPTOR.message_types_by_name['BindPhoneSmsCodeRes']
_BINDEMAILSESCODEREQ = DESCRIPTOR.message_types_by_name['BindEmailSesCodeReq']
_BINDEMAILSESCODERES = DESCRIPTOR.message_types_by_name['BindEmailSesCodeRes']
_ACCOUNTBINDEMAILSESREQ = DESCRIPTOR.message_types_by_name['AccountBindEmailSESReq']
_ACCOUNTBINDEMAILSESRES = DESCRIPTOR.message_types_by_name['AccountBindEmailSESRes']
_GETACCOUNTREGISTERREQ = DESCRIPTOR.message_types_by_name['GetAccountRegisterReq']
_GETACCOUNTPASSWORDLOGINREQ = DESCRIPTOR.message_types_by_name['GetAccountPasswordLoginReq']
_GETSESCODEREQ = DESCRIPTOR.message_types_by_name['GetSesCodeReq']
_GETSESCODERES = DESCRIPTOR.message_types_by_name['GetSesCodeRes']
_GETSESTOKENREQ = DESCRIPTOR.message_types_by_name['GetSesTokenReq']
_GETSESTOKENRES = DESCRIPTOR.message_types_by_name['GetSesTokenRes']
_RESETPASSWORDBYSESREQ = DESCRIPTOR.message_types_by_name['ResetPasswordBySesReq']
_RESETPASSWORDBYSESRES = DESCRIPTOR.message_types_by_name['ResetPasswordBySesRes']
_REMOTELOGINSENDCODEREQ = DESCRIPTOR.message_types_by_name['RemoteLoginSendCodeReq']
_REMOTELOGINSENDCODERES = DESCRIPTOR.message_types_by_name['RemoteLoginSendCodeRes']
_REMOTELOGINCONFIRMCODEREQ = DESCRIPTOR.message_types_by_name['RemoteLoginConfirmCodeReq']
_REMOTELOGINCONFIRMCODERES = DESCRIPTOR.message_types_by_name['RemoteLoginConfirmCodeRes']
_VERIFYCANCELSIGNINWITHAPPLEREQ = DESCRIPTOR.message_types_by_name['VerifyCancelSignInWithAppleReq']
_VERIFYCANCELSIGNINWITHAPPLERES = DESCRIPTOR.message_types_by_name['VerifyCancelSignInWithAppleRes']
_WECHATCODELOGINTICKETREQ = DESCRIPTOR.message_types_by_name['WechatCodeLoginTicketReq']
_WECHATCODELOGINTICKETRES = DESCRIPTOR.message_types_by_name['WechatCodeLoginTicketRes']
_GETWECHATMINICODEREQ = DESCRIPTOR.message_types_by_name['GetWechatMiniCodeReq']
_GETWECHATMINICODERES = DESCRIPTOR.message_types_by_name['GetWechatMiniCodeRes']
_GETWECHATMINICODESCANREQ = DESCRIPTOR.message_types_by_name['GetWechatMiniCodeScanReq']
_GETWECHATMINICODESCANRES = DESCRIPTOR.message_types_by_name['GetWechatMiniCodeScanRes']
_REFUSEPHONELICENSEREQ = DESCRIPTOR.message_types_by_name['RefusePhoneLicenseReq']
_REFUSEPHONELICENSERES = DESCRIPTOR.message_types_by_name['RefusePhoneLicenseRes']
_WECHATMINIBINDPHONEREQ = DESCRIPTOR.message_types_by_name['WechatMiniBindPhoneReq']
_WECHATMINIBINDPHONERES = DESCRIPTOR.message_types_by_name['WechatMiniBindPhoneRes']
_THIRDACCOUNTBINDWECHATINFO = DESCRIPTOR.message_types_by_name['ThirdAccountBindWeChatInfo']
_THIRDACCOUNTBINDQQINFO = DESCRIPTOR.message_types_by_name['ThirdAccountBindQqInfo']
_THIRDACCOUNTBINDINFO = DESCRIPTOR.message_types_by_name['ThirdAccountBindInfo']
_THIRDACCOUNTBINDINFODATA = DESCRIPTOR.message_types_by_name['ThirdAccountBindInfoData']
_THIRDACCOUNTBINDINFOREQ = DESCRIPTOR.message_types_by_name['ThirdAccountBindInfoReq']
_THIRDACCOUNTBINDINFORES = DESCRIPTOR.message_types_by_name['ThirdAccountBindInfoRes']
_BINDTHIRDACCOUNTREQ = DESCRIPTOR.message_types_by_name['BindThirdAccountReq']
_BINDTHIRDACCOUNTRES = DESCRIPTOR.message_types_by_name['BindThirdAccountRes']
_UNBINDTHIRDACCOUNTREQ = DESCRIPTOR.message_types_by_name['UnbindThirdAccountReq']
_UNBINDTHIRDACCOUNTRES = DESCRIPTOR.message_types_by_name['UnbindThirdAccountRes']
_GETQRCODELOGINCODEREQ = DESCRIPTOR.message_types_by_name['GetQrcodeLoginCodeReq']
_GETQRCODELOGINCODERES = DESCRIPTOR.message_types_by_name['GetQrcodeLoginCodeRes']
_QRCODESCANLOGINREQ = DESCRIPTOR.message_types_by_name['QrcodeScanLoginReq']
_QRCODESCANLOGINRES = DESCRIPTOR.message_types_by_name['QrcodeScanLoginRes']
_GETQRCODELOGINSTATUSREQ = DESCRIPTOR.message_types_by_name['GetQrcodeLoginStatusReq']
_GETQRCODELOGINSTATUSRES = DESCRIPTOR.message_types_by_name['GetQrcodeLoginStatusRes']
_SETQRCODELOGINSTATUSREQ = DESCRIPTOR.message_types_by_name['SetQrcodeLoginStatusReq']
_SETQRCODELOGINSTATUSRES = DESCRIPTOR.message_types_by_name['SetQrcodeLoginStatusRes']
_GETACCOUNTREGISTERSTATUSREQ = DESCRIPTOR.message_types_by_name['GetAccountRegisterStatusReq']
_GETACCOUNTREGISTERSTATUSRES = DESCRIPTOR.message_types_by_name['GetAccountRegisterStatusRes']
_GETUMENGPHONEREQ = DESCRIPTOR.message_types_by_name['GetUmengPhoneReq']
_GETUMENGPHONERES = DESCRIPTOR.message_types_by_name['GetUmengPhoneRes']
_ACCOUNTCROSSTYPEINFO = DESCRIPTOR.message_types_by_name['AccountCrossTypeInfo']
_ACCOUNTCROSSTYPEINFOREQ = DESCRIPTOR.message_types_by_name['AccountCrossTypeInfoReq']
_ACCOUNTCROSSTYPEINFORES = DESCRIPTOR.message_types_by_name['AccountCrossTypeInfoRes']
_APPLYACCOUNTCROSSTYPEREQ = DESCRIPTOR.message_types_by_name['ApplyAccountCrossTypeReq']
_APPLYACCOUNTCROSSTYPERES = DESCRIPTOR.message_types_by_name['ApplyAccountCrossTypeRes']
_CHECKINAPPCHARGELIMITREQ = DESCRIPTOR.message_types_by_name['CheckInAppChargeLimitReq']
_CHECKINAPPCHARGELIMITRES = DESCRIPTOR.message_types_by_name['CheckInAppChargeLimitRes']
_GETALIPAYMINIORDERREQ = DESCRIPTOR.message_types_by_name['GetAlipayMiniOrderReq']
_GETALIPAYMINIORDERREQ_EXTENDSENTRY = _GETALIPAYMINIORDERREQ.nested_types_by_name['ExtendsEntry']
_GETALIPAYMINIORDERRES = DESCRIPTOR.message_types_by_name['GetAlipayMiniOrderRes']
_GETGOODSLISTREQ = DESCRIPTOR.message_types_by_name['GetGoodsListReq']
_GETGOODSLISTRES = DESCRIPTOR.message_types_by_name['GetGoodsListRes']
_ALIPAYMINIINDEXITEM = DESCRIPTOR.message_types_by_name['AlipayMiniIndexItem']
_ALIPAYMINIINDEXBANNER = DESCRIPTOR.message_types_by_name['AlipayMiniIndexBanner']
_ALIPAYMINIINDEXGOODSLIST = DESCRIPTOR.message_types_by_name['AlipayMiniIndexGoodsList']
_ALIPAYMINIINDEXGOODSITEM = DESCRIPTOR.message_types_by_name['AlipayMiniIndexGoodsItem']
VerifyIAPReq = _reflection.GeneratedProtocolMessageType('VerifyIAPReq', (_message.Message,), {
  'DESCRIPTOR' : _VERIFYIAPREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.VerifyIAPReq)
  })
_sym_db.RegisterMessage(VerifyIAPReq)

VerifyIAPRes = _reflection.GeneratedProtocolMessageType('VerifyIAPRes', (_message.Message,), {
  'DESCRIPTOR' : _VERIFYIAPRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.VerifyIAPRes)
  })
_sym_db.RegisterMessage(VerifyIAPRes)

GoldCard = _reflection.GeneratedProtocolMessageType('GoldCard', (_message.Message,), {
  'DESCRIPTOR' : _GOLDCARD,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GoldCard)
  })
_sym_db.RegisterMessage(GoldCard)

GetGoodListReq = _reflection.GeneratedProtocolMessageType('GetGoodListReq', (_message.Message,), {
  'DESCRIPTOR' : _GETGOODLISTREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetGoodListReq)
  })
_sym_db.RegisterMessage(GetGoodListReq)

GetGoodListRes = _reflection.GeneratedProtocolMessageType('GetGoodListRes', (_message.Message,), {
  'DESCRIPTOR' : _GETGOODLISTRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetGoodListRes)
  })
_sym_db.RegisterMessage(GetGoodListRes)

OrderIAPReq = _reflection.GeneratedProtocolMessageType('OrderIAPReq', (_message.Message,), {
  'DESCRIPTOR' : _ORDERIAPREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.OrderIAPReq)
  })
_sym_db.RegisterMessage(OrderIAPReq)

OrderIAPRes = _reflection.GeneratedProtocolMessageType('OrderIAPRes', (_message.Message,), {
  'DESCRIPTOR' : _ORDERIAPRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.OrderIAPRes)
  })
_sym_db.RegisterMessage(OrderIAPRes)

CloseOrderIAPReq = _reflection.GeneratedProtocolMessageType('CloseOrderIAPReq', (_message.Message,), {
  'DESCRIPTOR' : _CLOSEORDERIAPREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.CloseOrderIAPReq)
  })
_sym_db.RegisterMessage(CloseOrderIAPReq)

CloseOrderIAPRes = _reflection.GeneratedProtocolMessageType('CloseOrderIAPRes', (_message.Message,), {
  'DESCRIPTOR' : _CLOSEORDERIAPRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.CloseOrderIAPRes)
  })
_sym_db.RegisterMessage(CloseOrderIAPRes)

VIPChargeAccountInfoReq = _reflection.GeneratedProtocolMessageType('VIPChargeAccountInfoReq', (_message.Message,), {
  'DESCRIPTOR' : _VIPCHARGEACCOUNTINFOREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.VIPChargeAccountInfoReq)
  })
_sym_db.RegisterMessage(VIPChargeAccountInfoReq)

VIPChargeAccountInfoRes = _reflection.GeneratedProtocolMessageType('VIPChargeAccountInfoRes', (_message.Message,), {
  'DESCRIPTOR' : _VIPCHARGEACCOUNTINFORES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.VIPChargeAccountInfoRes)
  })
_sym_db.RegisterMessage(VIPChargeAccountInfoRes)

VIPChargeLogReq = _reflection.GeneratedProtocolMessageType('VIPChargeLogReq', (_message.Message,), {
  'DESCRIPTOR' : _VIPCHARGELOGREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.VIPChargeLogReq)
  })
_sym_db.RegisterMessage(VIPChargeLogReq)

VIPChargeLogRes = _reflection.GeneratedProtocolMessageType('VIPChargeLogRes', (_message.Message,), {
  'DESCRIPTOR' : _VIPCHARGELOGRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.VIPChargeLogRes)
  })
_sym_db.RegisterMessage(VIPChargeLogRes)

VIPChargeLogs = _reflection.GeneratedProtocolMessageType('VIPChargeLogs', (_message.Message,), {
  'DESCRIPTOR' : _VIPCHARGELOGS,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.VIPChargeLogs)
  })
_sym_db.RegisterMessage(VIPChargeLogs)

VIPChargeItem = _reflection.GeneratedProtocolMessageType('VIPChargeItem', (_message.Message,), {
  'DESCRIPTOR' : _VIPCHARGEITEM,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.VIPChargeItem)
  })
_sym_db.RegisterMessage(VIPChargeItem)

ReportDataReq = _reflection.GeneratedProtocolMessageType('ReportDataReq', (_message.Message,), {
  'DESCRIPTOR' : _REPORTDATAREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.ReportDataReq)
  })
_sym_db.RegisterMessage(ReportDataReq)

ReportDataRes = _reflection.GeneratedProtocolMessageType('ReportDataRes', (_message.Message,), {
  'DESCRIPTOR' : _REPORTDATARES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.ReportDataRes)
  })
_sym_db.RegisterMessage(ReportDataRes)

GetChargeReq = _reflection.GeneratedProtocolMessageType('GetChargeReq', (_message.Message,), {

  'ExtendsEntry' : _reflection.GeneratedProtocolMessageType('ExtendsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETCHARGEREQ_EXTENDSENTRY,
    '__module__' : 'uauth_ext_pb2'
    # @@protoc_insertion_point(class_scope:uauth_pb.GetChargeReq.ExtendsEntry)
    })
  ,

  'ExtraDataEntry' : _reflection.GeneratedProtocolMessageType('ExtraDataEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETCHARGEREQ_EXTRADATAENTRY,
    '__module__' : 'uauth_ext_pb2'
    # @@protoc_insertion_point(class_scope:uauth_pb.GetChargeReq.ExtraDataEntry)
    })
  ,
  'DESCRIPTOR' : _GETCHARGEREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetChargeReq)
  })
_sym_db.RegisterMessage(GetChargeReq)
_sym_db.RegisterMessage(GetChargeReq.ExtendsEntry)
_sym_db.RegisterMessage(GetChargeReq.ExtraDataEntry)

GetChargeRes = _reflection.GeneratedProtocolMessageType('GetChargeRes', (_message.Message,), {
  'DESCRIPTOR' : _GETCHARGERES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetChargeRes)
  })
_sym_db.RegisterMessage(GetChargeRes)

GetSmsCodeReq = _reflection.GeneratedProtocolMessageType('GetSmsCodeReq', (_message.Message,), {
  'DESCRIPTOR' : _GETSMSCODEREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetSmsCodeReq)
  })
_sym_db.RegisterMessage(GetSmsCodeReq)

GetSmsCodeRes = _reflection.GeneratedProtocolMessageType('GetSmsCodeRes', (_message.Message,), {
  'DESCRIPTOR' : _GETSMSCODERES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetSmsCodeRes)
  })
_sym_db.RegisterMessage(GetSmsCodeRes)

GetSmsTokenReq = _reflection.GeneratedProtocolMessageType('GetSmsTokenReq', (_message.Message,), {
  'DESCRIPTOR' : _GETSMSTOKENREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetSmsTokenReq)
  })
_sym_db.RegisterMessage(GetSmsTokenReq)

GetSmsTokenRes = _reflection.GeneratedProtocolMessageType('GetSmsTokenRes', (_message.Message,), {
  'DESCRIPTOR' : _GETSMSTOKENRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetSmsTokenRes)
  })
_sym_db.RegisterMessage(GetSmsTokenRes)

PhoneSmsCodeReq = _reflection.GeneratedProtocolMessageType('PhoneSmsCodeReq', (_message.Message,), {
  'DESCRIPTOR' : _PHONESMSCODEREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.PhoneSmsCodeReq)
  })
_sym_db.RegisterMessage(PhoneSmsCodeReq)

PhoneSmsCodeRes = _reflection.GeneratedProtocolMessageType('PhoneSmsCodeRes', (_message.Message,), {
  'DESCRIPTOR' : _PHONESMSCODERES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.PhoneSmsCodeRes)
  })
_sym_db.RegisterMessage(PhoneSmsCodeRes)

CheckPhoneSmsCodeReq = _reflection.GeneratedProtocolMessageType('CheckPhoneSmsCodeReq', (_message.Message,), {
  'DESCRIPTOR' : _CHECKPHONESMSCODEREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.CheckPhoneSmsCodeReq)
  })
_sym_db.RegisterMessage(CheckPhoneSmsCodeReq)

CheckPhoneSmsCodeRes = _reflection.GeneratedProtocolMessageType('CheckPhoneSmsCodeRes', (_message.Message,), {
  'DESCRIPTOR' : _CHECKPHONESMSCODERES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.CheckPhoneSmsCodeRes)
  })
_sym_db.RegisterMessage(CheckPhoneSmsCodeRes)

CommonSignInRes = _reflection.GeneratedProtocolMessageType('CommonSignInRes', (_message.Message,), {

  'ExtendsEntry' : _reflection.GeneratedProtocolMessageType('ExtendsEntry', (_message.Message,), {
    'DESCRIPTOR' : _COMMONSIGNINRES_EXTENDSENTRY,
    '__module__' : 'uauth_ext_pb2'
    # @@protoc_insertion_point(class_scope:uauth_pb.CommonSignInRes.ExtendsEntry)
    })
  ,
  'DESCRIPTOR' : _COMMONSIGNINRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.CommonSignInRes)
  })
_sym_db.RegisterMessage(CommonSignInRes)
_sym_db.RegisterMessage(CommonSignInRes.ExtendsEntry)

SignInWithAppleReq = _reflection.GeneratedProtocolMessageType('SignInWithAppleReq', (_message.Message,), {
  'DESCRIPTOR' : _SIGNINWITHAPPLEREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.SignInWithAppleReq)
  })
_sym_db.RegisterMessage(SignInWithAppleReq)

IdOrPhoneLoginReq = _reflection.GeneratedProtocolMessageType('IdOrPhoneLoginReq', (_message.Message,), {
  'DESCRIPTOR' : _IDORPHONELOGINREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.IdOrPhoneLoginReq)
  })
_sym_db.RegisterMessage(IdOrPhoneLoginReq)

LoginWithPhoneSMSReq = _reflection.GeneratedProtocolMessageType('LoginWithPhoneSMSReq', (_message.Message,), {
  'DESCRIPTOR' : _LOGINWITHPHONESMSREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.LoginWithPhoneSMSReq)
  })
_sym_db.RegisterMessage(LoginWithPhoneSMSReq)

ThirdLoginReq = _reflection.GeneratedProtocolMessageType('ThirdLoginReq', (_message.Message,), {
  'DESCRIPTOR' : _THIRDLOGINREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.ThirdLoginReq)
  })
_sym_db.RegisterMessage(ThirdLoginReq)

ChinaMobileQuickLoginReq = _reflection.GeneratedProtocolMessageType('ChinaMobileQuickLoginReq', (_message.Message,), {
  'DESCRIPTOR' : _CHINAMOBILEQUICKLOGINREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.ChinaMobileQuickLoginReq)
  })
_sym_db.RegisterMessage(ChinaMobileQuickLoginReq)

ChinaTelecomAuthReq = _reflection.GeneratedProtocolMessageType('ChinaTelecomAuthReq', (_message.Message,), {
  'DESCRIPTOR' : _CHINATELECOMAUTHREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.ChinaTelecomAuthReq)
  })
_sym_db.RegisterMessage(ChinaTelecomAuthReq)

UmengQuickLoginReq = _reflection.GeneratedProtocolMessageType('UmengQuickLoginReq', (_message.Message,), {
  'DESCRIPTOR' : _UMENGQUICKLOGINREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.UmengQuickLoginReq)
  })
_sym_db.RegisterMessage(UmengQuickLoginReq)

DevLoginReq = _reflection.GeneratedProtocolMessageType('DevLoginReq', (_message.Message,), {
  'DESCRIPTOR' : _DEVLOGINREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.DevLoginReq)
  })
_sym_db.RegisterMessage(DevLoginReq)

ResetPasswordReq = _reflection.GeneratedProtocolMessageType('ResetPasswordReq', (_message.Message,), {
  'DESCRIPTOR' : _RESETPASSWORDREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.ResetPasswordReq)
  })
_sym_db.RegisterMessage(ResetPasswordReq)

ResetPasswordRes = _reflection.GeneratedProtocolMessageType('ResetPasswordRes', (_message.Message,), {
  'DESCRIPTOR' : _RESETPASSWORDRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.ResetPasswordRes)
  })
_sym_db.RegisterMessage(ResetPasswordRes)

LoginSecretReq = _reflection.GeneratedProtocolMessageType('LoginSecretReq', (_message.Message,), {
  'DESCRIPTOR' : _LOGINSECRETREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.LoginSecretReq)
  })
_sym_db.RegisterMessage(LoginSecretReq)

LoginSecretRes = _reflection.GeneratedProtocolMessageType('LoginSecretRes', (_message.Message,), {
  'DESCRIPTOR' : _LOGINSECRETRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.LoginSecretRes)
  })
_sym_db.RegisterMessage(LoginSecretRes)

UpdatePasswdReq = _reflection.GeneratedProtocolMessageType('UpdatePasswdReq', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPASSWDREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.UpdatePasswdReq)
  })
_sym_db.RegisterMessage(UpdatePasswdReq)

UpdatePasswdRes = _reflection.GeneratedProtocolMessageType('UpdatePasswdRes', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPASSWDRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.UpdatePasswdRes)
  })
_sym_db.RegisterMessage(UpdatePasswdRes)

InviteReq = _reflection.GeneratedProtocolMessageType('InviteReq', (_message.Message,), {
  'DESCRIPTOR' : _INVITEREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.InviteReq)
  })
_sym_db.RegisterMessage(InviteReq)

InviteRes = _reflection.GeneratedProtocolMessageType('InviteRes', (_message.Message,), {
  'DESCRIPTOR' : _INVITERES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.InviteRes)
  })
_sym_db.RegisterMessage(InviteRes)

GetSyncTimeReq = _reflection.GeneratedProtocolMessageType('GetSyncTimeReq', (_message.Message,), {
  'DESCRIPTOR' : _GETSYNCTIMEREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetSyncTimeReq)
  })
_sym_db.RegisterMessage(GetSyncTimeReq)

GetSyncTimeRes = _reflection.GeneratedProtocolMessageType('GetSyncTimeRes', (_message.Message,), {
  'DESCRIPTOR' : _GETSYNCTIMERES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetSyncTimeRes)
  })
_sym_db.RegisterMessage(GetSyncTimeRes)

ReportBuyNobilityReq = _reflection.GeneratedProtocolMessageType('ReportBuyNobilityReq', (_message.Message,), {
  'DESCRIPTOR' : _REPORTBUYNOBILITYREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.ReportBuyNobilityReq)
  })
_sym_db.RegisterMessage(ReportBuyNobilityReq)

ReportBuyNobilityRes = _reflection.GeneratedProtocolMessageType('ReportBuyNobilityRes', (_message.Message,), {
  'DESCRIPTOR' : _REPORTBUYNOBILITYRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.ReportBuyNobilityRes)
  })
_sym_db.RegisterMessage(ReportBuyNobilityRes)

GoogleIABNotifyReq = _reflection.GeneratedProtocolMessageType('GoogleIABNotifyReq', (_message.Message,), {

  'BuyIntent' : _reflection.GeneratedProtocolMessageType('BuyIntent', (_message.Message,), {
    'DESCRIPTOR' : _GOOGLEIABNOTIFYREQ_BUYINTENT,
    '__module__' : 'uauth_ext_pb2'
    # @@protoc_insertion_point(class_scope:uauth_pb.GoogleIABNotifyReq.BuyIntent)
    })
  ,
  'DESCRIPTOR' : _GOOGLEIABNOTIFYREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GoogleIABNotifyReq)
  })
_sym_db.RegisterMessage(GoogleIABNotifyReq)
_sym_db.RegisterMessage(GoogleIABNotifyReq.BuyIntent)

GoogleIABNotifyRes = _reflection.GeneratedProtocolMessageType('GoogleIABNotifyRes', (_message.Message,), {
  'DESCRIPTOR' : _GOOGLEIABNOTIFYRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GoogleIABNotifyRes)
  })
_sym_db.RegisterMessage(GoogleIABNotifyRes)

GoogleIABProductItem = _reflection.GeneratedProtocolMessageType('GoogleIABProductItem', (_message.Message,), {
  'DESCRIPTOR' : _GOOGLEIABPRODUCTITEM,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GoogleIABProductItem)
  })
_sym_db.RegisterMessage(GoogleIABProductItem)

GoogleIABProductItemsReq = _reflection.GeneratedProtocolMessageType('GoogleIABProductItemsReq', (_message.Message,), {
  'DESCRIPTOR' : _GOOGLEIABPRODUCTITEMSREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GoogleIABProductItemsReq)
  })
_sym_db.RegisterMessage(GoogleIABProductItemsReq)

GoogleIABProductItemsRes = _reflection.GeneratedProtocolMessageType('GoogleIABProductItemsRes', (_message.Message,), {
  'DESCRIPTOR' : _GOOGLEIABPRODUCTITEMSRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GoogleIABProductItemsRes)
  })
_sym_db.RegisterMessage(GoogleIABProductItemsRes)

GetWeChatAppIdReq = _reflection.GeneratedProtocolMessageType('GetWeChatAppIdReq', (_message.Message,), {
  'DESCRIPTOR' : _GETWECHATAPPIDREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetWeChatAppIdReq)
  })
_sym_db.RegisterMessage(GetWeChatAppIdReq)

GetWeChatAppIdRes = _reflection.GeneratedProtocolMessageType('GetWeChatAppIdRes', (_message.Message,), {
  'DESCRIPTOR' : _GETWECHATAPPIDRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetWeChatAppIdRes)
  })
_sym_db.RegisterMessage(GetWeChatAppIdRes)

GetWeChatIdLoginReq = _reflection.GeneratedProtocolMessageType('GetWeChatIdLoginReq', (_message.Message,), {
  'DESCRIPTOR' : _GETWECHATIDLOGINREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetWeChatIdLoginReq)
  })
_sym_db.RegisterMessage(GetWeChatIdLoginReq)

GetWeChatIdLoginRes = _reflection.GeneratedProtocolMessageType('GetWeChatIdLoginRes', (_message.Message,), {
  'DESCRIPTOR' : _GETWECHATIDLOGINRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetWeChatIdLoginRes)
  })
_sym_db.RegisterMessage(GetWeChatIdLoginRes)

UserInfo = _reflection.GeneratedProtocolMessageType('UserInfo', (_message.Message,), {
  'DESCRIPTOR' : _USERINFO,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.UserInfo)
  })
_sym_db.RegisterMessage(UserInfo)

GetMiniProgramLoginReq = _reflection.GeneratedProtocolMessageType('GetMiniProgramLoginReq', (_message.Message,), {
  'DESCRIPTOR' : _GETMINIPROGRAMLOGINREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetMiniProgramLoginReq)
  })
_sym_db.RegisterMessage(GetMiniProgramLoginReq)

MiniProgramPhoneReq = _reflection.GeneratedProtocolMessageType('MiniProgramPhoneReq', (_message.Message,), {
  'DESCRIPTOR' : _MINIPROGRAMPHONEREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.MiniProgramPhoneReq)
  })
_sym_db.RegisterMessage(MiniProgramPhoneReq)

MiniProgramPhoneRes = _reflection.GeneratedProtocolMessageType('MiniProgramPhoneRes', (_message.Message,), {
  'DESCRIPTOR' : _MINIPROGRAMPHONERES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.MiniProgramPhoneRes)
  })
_sym_db.RegisterMessage(MiniProgramPhoneRes)

ApplyCertifyReq = _reflection.GeneratedProtocolMessageType('ApplyCertifyReq', (_message.Message,), {
  'DESCRIPTOR' : _APPLYCERTIFYREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.ApplyCertifyReq)
  })
_sym_db.RegisterMessage(ApplyCertifyReq)

ApplyCertifyRes = _reflection.GeneratedProtocolMessageType('ApplyCertifyRes', (_message.Message,), {
  'DESCRIPTOR' : _APPLYCERTIFYRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.ApplyCertifyRes)
  })
_sym_db.RegisterMessage(ApplyCertifyRes)

ApplyCertifySignReq = _reflection.GeneratedProtocolMessageType('ApplyCertifySignReq', (_message.Message,), {
  'DESCRIPTOR' : _APPLYCERTIFYSIGNREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.ApplyCertifySignReq)
  })
_sym_db.RegisterMessage(ApplyCertifySignReq)

CertifyResultReq = _reflection.GeneratedProtocolMessageType('CertifyResultReq', (_message.Message,), {
  'DESCRIPTOR' : _CERTIFYRESULTREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.CertifyResultReq)
  })
_sym_db.RegisterMessage(CertifyResultReq)

CertifyResultRes = _reflection.GeneratedProtocolMessageType('CertifyResultRes', (_message.Message,), {
  'DESCRIPTOR' : _CERTIFYRESULTRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.CertifyResultRes)
  })
_sym_db.RegisterMessage(CertifyResultRes)

AccountPhoneSmsCodeReq = _reflection.GeneratedProtocolMessageType('AccountPhoneSmsCodeReq', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTPHONESMSCODEREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.AccountPhoneSmsCodeReq)
  })
_sym_db.RegisterMessage(AccountPhoneSmsCodeReq)

AccountPhoneSmsCodeRes = _reflection.GeneratedProtocolMessageType('AccountPhoneSmsCodeRes', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTPHONESMSCODERES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.AccountPhoneSmsCodeRes)
  })
_sym_db.RegisterMessage(AccountPhoneSmsCodeRes)

AccountSubsidiaryLoginReq = _reflection.GeneratedProtocolMessageType('AccountSubsidiaryLoginReq', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTSUBSIDIARYLOGINREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.AccountSubsidiaryLoginReq)
  })
_sym_db.RegisterMessage(AccountSubsidiaryLoginReq)

GetGuestLoginReq = _reflection.GeneratedProtocolMessageType('GetGuestLoginReq', (_message.Message,), {
  'DESCRIPTOR' : _GETGUESTLOGINREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetGuestLoginReq)
  })
_sym_db.RegisterMessage(GetGuestLoginReq)

AccountBindPhoneSMSReq = _reflection.GeneratedProtocolMessageType('AccountBindPhoneSMSReq', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTBINDPHONESMSREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.AccountBindPhoneSMSReq)
  })
_sym_db.RegisterMessage(AccountBindPhoneSMSReq)

AccountBindPhoneSMSRes = _reflection.GeneratedProtocolMessageType('AccountBindPhoneSMSRes', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTBINDPHONESMSRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.AccountBindPhoneSMSRes)
  })
_sym_db.RegisterMessage(AccountBindPhoneSMSRes)

AccountBindThirdReq = _reflection.GeneratedProtocolMessageType('AccountBindThirdReq', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTBINDTHIRDREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.AccountBindThirdReq)
  })
_sym_db.RegisterMessage(AccountBindThirdReq)

AccountBindThirdRes = _reflection.GeneratedProtocolMessageType('AccountBindThirdRes', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTBINDTHIRDRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.AccountBindThirdRes)
  })
_sym_db.RegisterMessage(AccountBindThirdRes)

AccountBindListReq = _reflection.GeneratedProtocolMessageType('AccountBindListReq', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTBINDLISTREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.AccountBindListReq)
  })
_sym_db.RegisterMessage(AccountBindListReq)

AccountBindListRes = _reflection.GeneratedProtocolMessageType('AccountBindListRes', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTBINDLISTRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.AccountBindListRes)
  })
_sym_db.RegisterMessage(AccountBindListRes)

BindPhoneSmsCodeReq = _reflection.GeneratedProtocolMessageType('BindPhoneSmsCodeReq', (_message.Message,), {
  'DESCRIPTOR' : _BINDPHONESMSCODEREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.BindPhoneSmsCodeReq)
  })
_sym_db.RegisterMessage(BindPhoneSmsCodeReq)

BindPhoneSmsCodeRes = _reflection.GeneratedProtocolMessageType('BindPhoneSmsCodeRes', (_message.Message,), {
  'DESCRIPTOR' : _BINDPHONESMSCODERES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.BindPhoneSmsCodeRes)
  })
_sym_db.RegisterMessage(BindPhoneSmsCodeRes)

BindEmailSesCodeReq = _reflection.GeneratedProtocolMessageType('BindEmailSesCodeReq', (_message.Message,), {
  'DESCRIPTOR' : _BINDEMAILSESCODEREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.BindEmailSesCodeReq)
  })
_sym_db.RegisterMessage(BindEmailSesCodeReq)

BindEmailSesCodeRes = _reflection.GeneratedProtocolMessageType('BindEmailSesCodeRes', (_message.Message,), {
  'DESCRIPTOR' : _BINDEMAILSESCODERES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.BindEmailSesCodeRes)
  })
_sym_db.RegisterMessage(BindEmailSesCodeRes)

AccountBindEmailSESReq = _reflection.GeneratedProtocolMessageType('AccountBindEmailSESReq', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTBINDEMAILSESREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.AccountBindEmailSESReq)
  })
_sym_db.RegisterMessage(AccountBindEmailSESReq)

AccountBindEmailSESRes = _reflection.GeneratedProtocolMessageType('AccountBindEmailSESRes', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTBINDEMAILSESRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.AccountBindEmailSESRes)
  })
_sym_db.RegisterMessage(AccountBindEmailSESRes)

GetAccountRegisterReq = _reflection.GeneratedProtocolMessageType('GetAccountRegisterReq', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTREGISTERREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetAccountRegisterReq)
  })
_sym_db.RegisterMessage(GetAccountRegisterReq)

GetAccountPasswordLoginReq = _reflection.GeneratedProtocolMessageType('GetAccountPasswordLoginReq', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTPASSWORDLOGINREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetAccountPasswordLoginReq)
  })
_sym_db.RegisterMessage(GetAccountPasswordLoginReq)

GetSesCodeReq = _reflection.GeneratedProtocolMessageType('GetSesCodeReq', (_message.Message,), {
  'DESCRIPTOR' : _GETSESCODEREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetSesCodeReq)
  })
_sym_db.RegisterMessage(GetSesCodeReq)

GetSesCodeRes = _reflection.GeneratedProtocolMessageType('GetSesCodeRes', (_message.Message,), {
  'DESCRIPTOR' : _GETSESCODERES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetSesCodeRes)
  })
_sym_db.RegisterMessage(GetSesCodeRes)

GetSesTokenReq = _reflection.GeneratedProtocolMessageType('GetSesTokenReq', (_message.Message,), {
  'DESCRIPTOR' : _GETSESTOKENREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetSesTokenReq)
  })
_sym_db.RegisterMessage(GetSesTokenReq)

GetSesTokenRes = _reflection.GeneratedProtocolMessageType('GetSesTokenRes', (_message.Message,), {
  'DESCRIPTOR' : _GETSESTOKENRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetSesTokenRes)
  })
_sym_db.RegisterMessage(GetSesTokenRes)

ResetPasswordBySesReq = _reflection.GeneratedProtocolMessageType('ResetPasswordBySesReq', (_message.Message,), {
  'DESCRIPTOR' : _RESETPASSWORDBYSESREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.ResetPasswordBySesReq)
  })
_sym_db.RegisterMessage(ResetPasswordBySesReq)

ResetPasswordBySesRes = _reflection.GeneratedProtocolMessageType('ResetPasswordBySesRes', (_message.Message,), {
  'DESCRIPTOR' : _RESETPASSWORDBYSESRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.ResetPasswordBySesRes)
  })
_sym_db.RegisterMessage(ResetPasswordBySesRes)

RemoteLoginSendCodeReq = _reflection.GeneratedProtocolMessageType('RemoteLoginSendCodeReq', (_message.Message,), {
  'DESCRIPTOR' : _REMOTELOGINSENDCODEREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.RemoteLoginSendCodeReq)
  })
_sym_db.RegisterMessage(RemoteLoginSendCodeReq)

RemoteLoginSendCodeRes = _reflection.GeneratedProtocolMessageType('RemoteLoginSendCodeRes', (_message.Message,), {
  'DESCRIPTOR' : _REMOTELOGINSENDCODERES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.RemoteLoginSendCodeRes)
  })
_sym_db.RegisterMessage(RemoteLoginSendCodeRes)

RemoteLoginConfirmCodeReq = _reflection.GeneratedProtocolMessageType('RemoteLoginConfirmCodeReq', (_message.Message,), {
  'DESCRIPTOR' : _REMOTELOGINCONFIRMCODEREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.RemoteLoginConfirmCodeReq)
  })
_sym_db.RegisterMessage(RemoteLoginConfirmCodeReq)

RemoteLoginConfirmCodeRes = _reflection.GeneratedProtocolMessageType('RemoteLoginConfirmCodeRes', (_message.Message,), {
  'DESCRIPTOR' : _REMOTELOGINCONFIRMCODERES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.RemoteLoginConfirmCodeRes)
  })
_sym_db.RegisterMessage(RemoteLoginConfirmCodeRes)

VerifyCancelSignInWithAppleReq = _reflection.GeneratedProtocolMessageType('VerifyCancelSignInWithAppleReq', (_message.Message,), {
  'DESCRIPTOR' : _VERIFYCANCELSIGNINWITHAPPLEREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.VerifyCancelSignInWithAppleReq)
  })
_sym_db.RegisterMessage(VerifyCancelSignInWithAppleReq)

VerifyCancelSignInWithAppleRes = _reflection.GeneratedProtocolMessageType('VerifyCancelSignInWithAppleRes', (_message.Message,), {
  'DESCRIPTOR' : _VERIFYCANCELSIGNINWITHAPPLERES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.VerifyCancelSignInWithAppleRes)
  })
_sym_db.RegisterMessage(VerifyCancelSignInWithAppleRes)

WechatCodeLoginTicketReq = _reflection.GeneratedProtocolMessageType('WechatCodeLoginTicketReq', (_message.Message,), {
  'DESCRIPTOR' : _WECHATCODELOGINTICKETREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.WechatCodeLoginTicketReq)
  })
_sym_db.RegisterMessage(WechatCodeLoginTicketReq)

WechatCodeLoginTicketRes = _reflection.GeneratedProtocolMessageType('WechatCodeLoginTicketRes', (_message.Message,), {
  'DESCRIPTOR' : _WECHATCODELOGINTICKETRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.WechatCodeLoginTicketRes)
  })
_sym_db.RegisterMessage(WechatCodeLoginTicketRes)

GetWechatMiniCodeReq = _reflection.GeneratedProtocolMessageType('GetWechatMiniCodeReq', (_message.Message,), {
  'DESCRIPTOR' : _GETWECHATMINICODEREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetWechatMiniCodeReq)
  })
_sym_db.RegisterMessage(GetWechatMiniCodeReq)

GetWechatMiniCodeRes = _reflection.GeneratedProtocolMessageType('GetWechatMiniCodeRes', (_message.Message,), {
  'DESCRIPTOR' : _GETWECHATMINICODERES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetWechatMiniCodeRes)
  })
_sym_db.RegisterMessage(GetWechatMiniCodeRes)

GetWechatMiniCodeScanReq = _reflection.GeneratedProtocolMessageType('GetWechatMiniCodeScanReq', (_message.Message,), {
  'DESCRIPTOR' : _GETWECHATMINICODESCANREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetWechatMiniCodeScanReq)
  })
_sym_db.RegisterMessage(GetWechatMiniCodeScanReq)

GetWechatMiniCodeScanRes = _reflection.GeneratedProtocolMessageType('GetWechatMiniCodeScanRes', (_message.Message,), {
  'DESCRIPTOR' : _GETWECHATMINICODESCANRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetWechatMiniCodeScanRes)
  })
_sym_db.RegisterMessage(GetWechatMiniCodeScanRes)

RefusePhoneLicenseReq = _reflection.GeneratedProtocolMessageType('RefusePhoneLicenseReq', (_message.Message,), {
  'DESCRIPTOR' : _REFUSEPHONELICENSEREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.RefusePhoneLicenseReq)
  })
_sym_db.RegisterMessage(RefusePhoneLicenseReq)

RefusePhoneLicenseRes = _reflection.GeneratedProtocolMessageType('RefusePhoneLicenseRes', (_message.Message,), {
  'DESCRIPTOR' : _REFUSEPHONELICENSERES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.RefusePhoneLicenseRes)
  })
_sym_db.RegisterMessage(RefusePhoneLicenseRes)

WechatMiniBindPhoneReq = _reflection.GeneratedProtocolMessageType('WechatMiniBindPhoneReq', (_message.Message,), {
  'DESCRIPTOR' : _WECHATMINIBINDPHONEREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.WechatMiniBindPhoneReq)
  })
_sym_db.RegisterMessage(WechatMiniBindPhoneReq)

WechatMiniBindPhoneRes = _reflection.GeneratedProtocolMessageType('WechatMiniBindPhoneRes', (_message.Message,), {
  'DESCRIPTOR' : _WECHATMINIBINDPHONERES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.WechatMiniBindPhoneRes)
  })
_sym_db.RegisterMessage(WechatMiniBindPhoneRes)

ThirdAccountBindWeChatInfo = _reflection.GeneratedProtocolMessageType('ThirdAccountBindWeChatInfo', (_message.Message,), {
  'DESCRIPTOR' : _THIRDACCOUNTBINDWECHATINFO,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.ThirdAccountBindWeChatInfo)
  })
_sym_db.RegisterMessage(ThirdAccountBindWeChatInfo)

ThirdAccountBindQqInfo = _reflection.GeneratedProtocolMessageType('ThirdAccountBindQqInfo', (_message.Message,), {
  'DESCRIPTOR' : _THIRDACCOUNTBINDQQINFO,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.ThirdAccountBindQqInfo)
  })
_sym_db.RegisterMessage(ThirdAccountBindQqInfo)

ThirdAccountBindInfo = _reflection.GeneratedProtocolMessageType('ThirdAccountBindInfo', (_message.Message,), {
  'DESCRIPTOR' : _THIRDACCOUNTBINDINFO,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.ThirdAccountBindInfo)
  })
_sym_db.RegisterMessage(ThirdAccountBindInfo)

ThirdAccountBindInfoData = _reflection.GeneratedProtocolMessageType('ThirdAccountBindInfoData', (_message.Message,), {
  'DESCRIPTOR' : _THIRDACCOUNTBINDINFODATA,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.ThirdAccountBindInfoData)
  })
_sym_db.RegisterMessage(ThirdAccountBindInfoData)

ThirdAccountBindInfoReq = _reflection.GeneratedProtocolMessageType('ThirdAccountBindInfoReq', (_message.Message,), {
  'DESCRIPTOR' : _THIRDACCOUNTBINDINFOREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.ThirdAccountBindInfoReq)
  })
_sym_db.RegisterMessage(ThirdAccountBindInfoReq)

ThirdAccountBindInfoRes = _reflection.GeneratedProtocolMessageType('ThirdAccountBindInfoRes', (_message.Message,), {
  'DESCRIPTOR' : _THIRDACCOUNTBINDINFORES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.ThirdAccountBindInfoRes)
  })
_sym_db.RegisterMessage(ThirdAccountBindInfoRes)

BindThirdAccountReq = _reflection.GeneratedProtocolMessageType('BindThirdAccountReq', (_message.Message,), {
  'DESCRIPTOR' : _BINDTHIRDACCOUNTREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.BindThirdAccountReq)
  })
_sym_db.RegisterMessage(BindThirdAccountReq)

BindThirdAccountRes = _reflection.GeneratedProtocolMessageType('BindThirdAccountRes', (_message.Message,), {
  'DESCRIPTOR' : _BINDTHIRDACCOUNTRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.BindThirdAccountRes)
  })
_sym_db.RegisterMessage(BindThirdAccountRes)

UnbindThirdAccountReq = _reflection.GeneratedProtocolMessageType('UnbindThirdAccountReq', (_message.Message,), {
  'DESCRIPTOR' : _UNBINDTHIRDACCOUNTREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.UnbindThirdAccountReq)
  })
_sym_db.RegisterMessage(UnbindThirdAccountReq)

UnbindThirdAccountRes = _reflection.GeneratedProtocolMessageType('UnbindThirdAccountRes', (_message.Message,), {
  'DESCRIPTOR' : _UNBINDTHIRDACCOUNTRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.UnbindThirdAccountRes)
  })
_sym_db.RegisterMessage(UnbindThirdAccountRes)

GetQrcodeLoginCodeReq = _reflection.GeneratedProtocolMessageType('GetQrcodeLoginCodeReq', (_message.Message,), {
  'DESCRIPTOR' : _GETQRCODELOGINCODEREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetQrcodeLoginCodeReq)
  })
_sym_db.RegisterMessage(GetQrcodeLoginCodeReq)

GetQrcodeLoginCodeRes = _reflection.GeneratedProtocolMessageType('GetQrcodeLoginCodeRes', (_message.Message,), {
  'DESCRIPTOR' : _GETQRCODELOGINCODERES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetQrcodeLoginCodeRes)
  })
_sym_db.RegisterMessage(GetQrcodeLoginCodeRes)

QrcodeScanLoginReq = _reflection.GeneratedProtocolMessageType('QrcodeScanLoginReq', (_message.Message,), {
  'DESCRIPTOR' : _QRCODESCANLOGINREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.QrcodeScanLoginReq)
  })
_sym_db.RegisterMessage(QrcodeScanLoginReq)

QrcodeScanLoginRes = _reflection.GeneratedProtocolMessageType('QrcodeScanLoginRes', (_message.Message,), {
  'DESCRIPTOR' : _QRCODESCANLOGINRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.QrcodeScanLoginRes)
  })
_sym_db.RegisterMessage(QrcodeScanLoginRes)

GetQrcodeLoginStatusReq = _reflection.GeneratedProtocolMessageType('GetQrcodeLoginStatusReq', (_message.Message,), {
  'DESCRIPTOR' : _GETQRCODELOGINSTATUSREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetQrcodeLoginStatusReq)
  })
_sym_db.RegisterMessage(GetQrcodeLoginStatusReq)

GetQrcodeLoginStatusRes = _reflection.GeneratedProtocolMessageType('GetQrcodeLoginStatusRes', (_message.Message,), {
  'DESCRIPTOR' : _GETQRCODELOGINSTATUSRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetQrcodeLoginStatusRes)
  })
_sym_db.RegisterMessage(GetQrcodeLoginStatusRes)

SetQrcodeLoginStatusReq = _reflection.GeneratedProtocolMessageType('SetQrcodeLoginStatusReq', (_message.Message,), {
  'DESCRIPTOR' : _SETQRCODELOGINSTATUSREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.SetQrcodeLoginStatusReq)
  })
_sym_db.RegisterMessage(SetQrcodeLoginStatusReq)

SetQrcodeLoginStatusRes = _reflection.GeneratedProtocolMessageType('SetQrcodeLoginStatusRes', (_message.Message,), {
  'DESCRIPTOR' : _SETQRCODELOGINSTATUSRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.SetQrcodeLoginStatusRes)
  })
_sym_db.RegisterMessage(SetQrcodeLoginStatusRes)

GetAccountRegisterStatusReq = _reflection.GeneratedProtocolMessageType('GetAccountRegisterStatusReq', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTREGISTERSTATUSREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetAccountRegisterStatusReq)
  })
_sym_db.RegisterMessage(GetAccountRegisterStatusReq)

GetAccountRegisterStatusRes = _reflection.GeneratedProtocolMessageType('GetAccountRegisterStatusRes', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTREGISTERSTATUSRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetAccountRegisterStatusRes)
  })
_sym_db.RegisterMessage(GetAccountRegisterStatusRes)

GetUmengPhoneReq = _reflection.GeneratedProtocolMessageType('GetUmengPhoneReq', (_message.Message,), {
  'DESCRIPTOR' : _GETUMENGPHONEREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetUmengPhoneReq)
  })
_sym_db.RegisterMessage(GetUmengPhoneReq)

GetUmengPhoneRes = _reflection.GeneratedProtocolMessageType('GetUmengPhoneRes', (_message.Message,), {
  'DESCRIPTOR' : _GETUMENGPHONERES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetUmengPhoneRes)
  })
_sym_db.RegisterMessage(GetUmengPhoneRes)

AccountCrossTypeInfo = _reflection.GeneratedProtocolMessageType('AccountCrossTypeInfo', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTCROSSTYPEINFO,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.AccountCrossTypeInfo)
  })
_sym_db.RegisterMessage(AccountCrossTypeInfo)

AccountCrossTypeInfoReq = _reflection.GeneratedProtocolMessageType('AccountCrossTypeInfoReq', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTCROSSTYPEINFOREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.AccountCrossTypeInfoReq)
  })
_sym_db.RegisterMessage(AccountCrossTypeInfoReq)

AccountCrossTypeInfoRes = _reflection.GeneratedProtocolMessageType('AccountCrossTypeInfoRes', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTCROSSTYPEINFORES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.AccountCrossTypeInfoRes)
  })
_sym_db.RegisterMessage(AccountCrossTypeInfoRes)

ApplyAccountCrossTypeReq = _reflection.GeneratedProtocolMessageType('ApplyAccountCrossTypeReq', (_message.Message,), {
  'DESCRIPTOR' : _APPLYACCOUNTCROSSTYPEREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.ApplyAccountCrossTypeReq)
  })
_sym_db.RegisterMessage(ApplyAccountCrossTypeReq)

ApplyAccountCrossTypeRes = _reflection.GeneratedProtocolMessageType('ApplyAccountCrossTypeRes', (_message.Message,), {
  'DESCRIPTOR' : _APPLYACCOUNTCROSSTYPERES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.ApplyAccountCrossTypeRes)
  })
_sym_db.RegisterMessage(ApplyAccountCrossTypeRes)

CheckInAppChargeLimitReq = _reflection.GeneratedProtocolMessageType('CheckInAppChargeLimitReq', (_message.Message,), {
  'DESCRIPTOR' : _CHECKINAPPCHARGELIMITREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.CheckInAppChargeLimitReq)
  })
_sym_db.RegisterMessage(CheckInAppChargeLimitReq)

CheckInAppChargeLimitRes = _reflection.GeneratedProtocolMessageType('CheckInAppChargeLimitRes', (_message.Message,), {
  'DESCRIPTOR' : _CHECKINAPPCHARGELIMITRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.CheckInAppChargeLimitRes)
  })
_sym_db.RegisterMessage(CheckInAppChargeLimitRes)

GetAlipayMiniOrderReq = _reflection.GeneratedProtocolMessageType('GetAlipayMiniOrderReq', (_message.Message,), {

  'ExtendsEntry' : _reflection.GeneratedProtocolMessageType('ExtendsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETALIPAYMINIORDERREQ_EXTENDSENTRY,
    '__module__' : 'uauth_ext_pb2'
    # @@protoc_insertion_point(class_scope:uauth_pb.GetAlipayMiniOrderReq.ExtendsEntry)
    })
  ,
  'DESCRIPTOR' : _GETALIPAYMINIORDERREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetAlipayMiniOrderReq)
  })
_sym_db.RegisterMessage(GetAlipayMiniOrderReq)
_sym_db.RegisterMessage(GetAlipayMiniOrderReq.ExtendsEntry)

GetAlipayMiniOrderRes = _reflection.GeneratedProtocolMessageType('GetAlipayMiniOrderRes', (_message.Message,), {
  'DESCRIPTOR' : _GETALIPAYMINIORDERRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetAlipayMiniOrderRes)
  })
_sym_db.RegisterMessage(GetAlipayMiniOrderRes)

GetGoodsListReq = _reflection.GeneratedProtocolMessageType('GetGoodsListReq', (_message.Message,), {
  'DESCRIPTOR' : _GETGOODSLISTREQ,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetGoodsListReq)
  })
_sym_db.RegisterMessage(GetGoodsListReq)

GetGoodsListRes = _reflection.GeneratedProtocolMessageType('GetGoodsListRes', (_message.Message,), {
  'DESCRIPTOR' : _GETGOODSLISTRES,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.GetGoodsListRes)
  })
_sym_db.RegisterMessage(GetGoodsListRes)

AlipayMiniIndexItem = _reflection.GeneratedProtocolMessageType('AlipayMiniIndexItem', (_message.Message,), {
  'DESCRIPTOR' : _ALIPAYMINIINDEXITEM,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.AlipayMiniIndexItem)
  })
_sym_db.RegisterMessage(AlipayMiniIndexItem)

AlipayMiniIndexBanner = _reflection.GeneratedProtocolMessageType('AlipayMiniIndexBanner', (_message.Message,), {
  'DESCRIPTOR' : _ALIPAYMINIINDEXBANNER,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.AlipayMiniIndexBanner)
  })
_sym_db.RegisterMessage(AlipayMiniIndexBanner)

AlipayMiniIndexGoodsList = _reflection.GeneratedProtocolMessageType('AlipayMiniIndexGoodsList', (_message.Message,), {
  'DESCRIPTOR' : _ALIPAYMINIINDEXGOODSLIST,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.AlipayMiniIndexGoodsList)
  })
_sym_db.RegisterMessage(AlipayMiniIndexGoodsList)

AlipayMiniIndexGoodsItem = _reflection.GeneratedProtocolMessageType('AlipayMiniIndexGoodsItem', (_message.Message,), {
  'DESCRIPTOR' : _ALIPAYMINIINDEXGOODSITEM,
  '__module__' : 'uauth_ext_pb2'
  # @@protoc_insertion_point(class_scope:uauth_pb.AlipayMiniIndexGoodsItem)
  })
_sym_db.RegisterMessage(AlipayMiniIndexGoodsItem)

_UAUTHEXTOBJ = DESCRIPTOR.services_by_name['UauthExtObj']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\242\002\005PROTO'
  _GETCHARGEREQ_EXTENDSENTRY._options = None
  _GETCHARGEREQ_EXTENDSENTRY._serialized_options = b'8\001'
  _GETCHARGEREQ_EXTRADATAENTRY._options = None
  _GETCHARGEREQ_EXTRADATAENTRY._serialized_options = b'8\001'
  _COMMONSIGNINRES_EXTENDSENTRY._options = None
  _COMMONSIGNINRES_EXTENDSENTRY._serialized_options = b'8\001'
  _GETALIPAYMINIORDERREQ_EXTENDSENTRY._options = None
  _GETALIPAYMINIORDERREQ_EXTENDSENTRY._serialized_options = b'8\001'
  _ERRORUAUTHCODE._serialized_start=11797
  _ERRORUAUTHCODE._serialized_end=12699
  _IAPSTATUSTYPE._serialized_start=12701
  _IAPSTATUSTYPE._serialized_end=12774
  _CHARGESTATUS._serialized_start=12776
  _CHARGESTATUS._serialized_end=12837
  _REPORTDATATYPE._serialized_start=12839
  _REPORTDATATYPE._serialized_end=12896
  _VERIFYTYPE._serialized_start=12898
  _VERIFYTYPE._serialized_end=12980
  _SMSCODETPL._serialized_start=12982
  _SMSCODETPL._serialized_end=13089
  _CERTIFYTYPE._serialized_start=13091
  _CERTIFYTYPE._serialized_end=13132
  _WECHATMINICODESCANSTATUS._serialized_start=13135
  _WECHATMINICODESCANSTATUS._serialized_end=13265
  _THIRDACCOUNTBINDTYPE._serialized_start=13267
  _THIRDACCOUNTBINDTYPE._serialized_end=13334
  _UNBINDTHIRDACCOUNTOPTTYPE._serialized_start=13336
  _UNBINDTHIRDACCOUNTOPTTYPE._serialized_end=13397
  _GETQRCODELOGINSTATUS._serialized_start=13399
  _GETQRCODELOGINSTATUS._serialized_end=13482
  _ACCOUNTREGISTERTYPE._serialized_start=13484
  _ACCOUNTREGISTERTYPE._serialized_end=13546
  _ACCOUNTAPPCROSSTYPE._serialized_start=13548
  _ACCOUNTAPPCROSSTYPE._serialized_end=13599
  _APPCHARGETYPE._serialized_start=13601
  _APPCHARGETYPE._serialized_end=13661
  _ALIPAYMINIINDEXTYPE._serialized_start=13663
  _ALIPAYMINIINDEXTYPE._serialized_end=13732
  _ALIPAYMINIGOODSTYPE._serialized_start=13734
  _ALIPAYMINIGOODSTYPE._serialized_end=13785
  _VERIFYIAPREQ._serialized_start=49
  _VERIFYIAPREQ._serialized_end=158
  _VERIFYIAPRES._serialized_start=160
  _VERIFYIAPRES._serialized_end=174
  _GOLDCARD._serialized_start=176
  _GOLDCARD._serialized_end=273
  _GETGOODLISTREQ._serialized_start=275
  _GETGOODLISTREQ._serialized_end=291
  _GETGOODLISTRES._serialized_start=293
  _GETGOODLISTRES._serialized_end=365
  _ORDERIAPREQ._serialized_start=367
  _ORDERIAPREQ._serialized_end=411
  _ORDERIAPRES._serialized_start=413
  _ORDERIAPRES._serialized_end=444
  _CLOSEORDERIAPREQ._serialized_start=446
  _CLOSEORDERIAPREQ._serialized_end=523
  _CLOSEORDERIAPRES._serialized_start=525
  _CLOSEORDERIAPRES._serialized_end=543
  _VIPCHARGEACCOUNTINFOREQ._serialized_start=545
  _VIPCHARGEACCOUNTINFOREQ._serialized_end=582
  _VIPCHARGEACCOUNTINFORES._serialized_start=585
  _VIPCHARGEACCOUNTINFORES._serialized_end=726
  _VIPCHARGELOGREQ._serialized_start=728
  _VIPCHARGELOGREQ._serialized_end=745
  _VIPCHARGELOGRES._serialized_start=747
  _VIPCHARGELOGRES._serialized_end=803
  _VIPCHARGELOGS._serialized_start=805
  _VIPCHARGELOGS._serialized_end=872
  _VIPCHARGEITEM._serialized_start=874
  _VIPCHARGEITEM._serialized_end=994
  _REPORTDATAREQ._serialized_start=996
  _REPORTDATAREQ._serialized_end=1065
  _REPORTDATARES._serialized_start=1067
  _REPORTDATARES._serialized_end=1082
  _GETCHARGEREQ._serialized_start=1085
  _GETCHARGEREQ._serialized_end=1461
  _GETCHARGEREQ_EXTENDSENTRY._serialized_start=1365
  _GETCHARGEREQ_EXTENDSENTRY._serialized_end=1411
  _GETCHARGEREQ_EXTRADATAENTRY._serialized_start=1413
  _GETCHARGEREQ_EXTRADATAENTRY._serialized_end=1461
  _GETCHARGERES._serialized_start=1463
  _GETCHARGERES._serialized_end=1543
  _GETSMSCODEREQ._serialized_start=1545
  _GETSMSCODEREQ._serialized_end=1659
  _GETSMSCODERES._serialized_start=1661
  _GETSMSCODERES._serialized_end=1676
  _GETSMSTOKENREQ._serialized_start=1679
  _GETSMSTOKENREQ._serialized_end=1812
  _GETSMSTOKENRES._serialized_start=1814
  _GETSMSTOKENRES._serialized_end=1849
  _PHONESMSCODEREQ._serialized_start=1851
  _PHONESMSCODEREQ._serialized_end=1912
  _PHONESMSCODERES._serialized_start=1914
  _PHONESMSCODERES._serialized_end=1931
  _CHECKPHONESMSCODEREQ._serialized_start=1933
  _CHECKPHONESMSCODEREQ._serialized_end=2017
  _CHECKPHONESMSCODERES._serialized_start=2019
  _CHECKPHONESMSCODERES._serialized_end=2041
  _COMMONSIGNINRES._serialized_start=2044
  _COMMONSIGNINRES._serialized_end=2266
  _COMMONSIGNINRES_EXTENDSENTRY._serialized_start=1365
  _COMMONSIGNINRES_EXTENDSENTRY._serialized_end=1411
  _SIGNINWITHAPPLEREQ._serialized_start=2269
  _SIGNINWITHAPPLEREQ._serialized_end=2475
  _IDORPHONELOGINREQ._serialized_start=2478
  _IDORPHONELOGINREQ._serialized_end=2627
  _LOGINWITHPHONESMSREQ._serialized_start=2630
  _LOGINWITHPHONESMSREQ._serialized_end=2921
  _THIRDLOGINREQ._serialized_start=2924
  _THIRDLOGINREQ._serialized_end=3212
  _CHINAMOBILEQUICKLOGINREQ._serialized_start=3215
  _CHINAMOBILEQUICKLOGINREQ._serialized_end=3425
  _CHINATELECOMAUTHREQ._serialized_start=3428
  _CHINATELECOMAUTHREQ._serialized_end=3624
  _UMENGQUICKLOGINREQ._serialized_start=3627
  _UMENGQUICKLOGINREQ._serialized_end=3832
  _DEVLOGINREQ._serialized_start=3835
  _DEVLOGINREQ._serialized_end=4015
  _RESETPASSWORDREQ._serialized_start=4018
  _RESETPASSWORDREQ._serialized_end=4161
  _RESETPASSWORDRES._serialized_start=4163
  _RESETPASSWORDRES._serialized_end=4181
  _LOGINSECRETREQ._serialized_start=4183
  _LOGINSECRETREQ._serialized_end=4199
  _LOGINSECRETRES._serialized_start=4201
  _LOGINSECRETRES._serialized_end=4230
  _UPDATEPASSWDREQ._serialized_start=4232
  _UPDATEPASSWDREQ._serialized_end=4319
  _UPDATEPASSWDRES._serialized_start=4321
  _UPDATEPASSWDRES._serialized_end=4338
  _INVITEREQ._serialized_start=4340
  _INVITEREQ._serialized_end=4400
  _INVITERES._serialized_start=4402
  _INVITERES._serialized_end=4413
  _GETSYNCTIMEREQ._serialized_start=4415
  _GETSYNCTIMEREQ._serialized_end=4431
  _GETSYNCTIMERES._serialized_start=4433
  _GETSYNCTIMERES._serialized_end=4449
  _REPORTBUYNOBILITYREQ._serialized_start=4451
  _REPORTBUYNOBILITYREQ._serialized_end=4510
  _REPORTBUYNOBILITYRES._serialized_start=4512
  _REPORTBUYNOBILITYRES._serialized_end=4534
  _GOOGLEIABNOTIFYREQ._serialized_start=4537
  _GOOGLEIABNOTIFYREQ._serialized_end=4716
  _GOOGLEIABNOTIFYREQ_BUYINTENT._serialized_start=4658
  _GOOGLEIABNOTIFYREQ_BUYINTENT._serialized_end=4716
  _GOOGLEIABNOTIFYRES._serialized_start=4718
  _GOOGLEIABNOTIFYRES._serialized_end=4738
  _GOOGLEIABPRODUCTITEM._serialized_start=4740
  _GOOGLEIABPRODUCTITEM._serialized_end=4817
  _GOOGLEIABPRODUCTITEMSREQ._serialized_start=4819
  _GOOGLEIABPRODUCTITEMSREQ._serialized_end=4845
  _GOOGLEIABPRODUCTITEMSRES._serialized_start=4847
  _GOOGLEIABPRODUCTITEMSRES._serialized_end=4920
  _GETWECHATAPPIDREQ._serialized_start=4922
  _GETWECHATAPPIDREQ._serialized_end=4941
  _GETWECHATAPPIDRES._serialized_start=4943
  _GETWECHATAPPIDRES._serialized_end=4978
  _GETWECHATIDLOGINREQ._serialized_start=4980
  _GETWECHATIDLOGINREQ._serialized_end=5015
  _GETWECHATIDLOGINRES._serialized_start=5017
  _GETWECHATIDLOGINRES._serialized_end=5088
  _USERINFO._serialized_start=5090
  _USERINFO._serialized_end=5148
  _GETMINIPROGRAMLOGINREQ._serialized_start=5151
  _GETMINIPROGRAMLOGINREQ._serialized_end=5391
  _MINIPROGRAMPHONEREQ._serialized_start=5393
  _MINIPROGRAMPHONEREQ._serialized_end=5510
  _MINIPROGRAMPHONERES._serialized_start=5512
  _MINIPROGRAMPHONERES._serialized_end=5533
  _APPLYCERTIFYREQ._serialized_start=5535
  _APPLYCERTIFYREQ._serialized_end=5628
  _APPLYCERTIFYRES._serialized_start=5630
  _APPLYCERTIFYRES._serialized_end=5728
  _APPLYCERTIFYSIGNREQ._serialized_start=5731
  _APPLYCERTIFYSIGNREQ._serialized_end=5869
  _CERTIFYRESULTREQ._serialized_start=5871
  _CERTIFYRESULTREQ._serialized_end=5889
  _CERTIFYRESULTRES._serialized_start=5891
  _CERTIFYRESULTRES._serialized_end=5985
  _ACCOUNTPHONESMSCODEREQ._serialized_start=5987
  _ACCOUNTPHONESMSCODEREQ._serialized_end=6011
  _ACCOUNTPHONESMSCODERES._serialized_start=6013
  _ACCOUNTPHONESMSCODERES._serialized_end=6037
  _ACCOUNTSUBSIDIARYLOGINREQ._serialized_start=6040
  _ACCOUNTSUBSIDIARYLOGINREQ._serialized_end=6238
  _GETGUESTLOGINREQ._serialized_start=6241
  _GETGUESTLOGINREQ._serialized_end=6379
  _ACCOUNTBINDPHONESMSREQ._serialized_start=6381
  _ACCOUNTBINDPHONESMSREQ._serialized_end=6478
  _ACCOUNTBINDPHONESMSRES._serialized_start=6480
  _ACCOUNTBINDPHONESMSRES._serialized_end=6504
  _ACCOUNTBINDTHIRDREQ._serialized_start=6507
  _ACCOUNTBINDTHIRDREQ._serialized_end=6648
  _ACCOUNTBINDTHIRDRES._serialized_start=6650
  _ACCOUNTBINDTHIRDRES._serialized_end=6671
  _ACCOUNTBINDLISTREQ._serialized_start=6673
  _ACCOUNTBINDLISTREQ._serialized_end=6693
  _ACCOUNTBINDLISTRES._serialized_start=6695
  _ACCOUNTBINDLISTRES._serialized_end=6785
  _BINDPHONESMSCODEREQ._serialized_start=6787
  _BINDPHONESMSCODEREQ._serialized_end=6883
  _BINDPHONESMSCODERES._serialized_start=6885
  _BINDPHONESMSCODERES._serialized_end=6906
  _BINDEMAILSESCODEREQ._serialized_start=6908
  _BINDEMAILSESCODEREQ._serialized_end=6984
  _BINDEMAILSESCODERES._serialized_start=6986
  _BINDEMAILSESCODERES._serialized_end=7007
  _ACCOUNTBINDEMAILSESREQ._serialized_start=7009
  _ACCOUNTBINDEMAILSESREQ._serialized_end=7106
  _ACCOUNTBINDEMAILSESRES._serialized_start=7108
  _ACCOUNTBINDEMAILSESRES._serialized_end=7132
  _GETACCOUNTREGISTERREQ._serialized_start=7135
  _GETACCOUNTREGISTERREQ._serialized_end=7361
  _GETACCOUNTPASSWORDLOGINREQ._serialized_start=7364
  _GETACCOUNTPASSWORDLOGINREQ._serialized_end=7543
  _GETSESCODEREQ._serialized_start=7545
  _GETSESCODEREQ._serialized_end=7595
  _GETSESCODERES._serialized_start=7597
  _GETSESCODERES._serialized_end=7612
  _GETSESTOKENREQ._serialized_start=7614
  _GETSESTOKENREQ._serialized_end=7683
  _GETSESTOKENRES._serialized_start=7685
  _GETSESTOKENRES._serialized_end=7720
  _RESETPASSWORDBYSESREQ._serialized_start=7722
  _RESETPASSWORDBYSESREQ._serialized_end=7831
  _RESETPASSWORDBYSESRES._serialized_start=7833
  _RESETPASSWORDBYSESRES._serialized_end=7856
  _REMOTELOGINSENDCODEREQ._serialized_start=7858
  _REMOTELOGINSENDCODEREQ._serialized_end=7899
  _REMOTELOGINSENDCODERES._serialized_start=7901
  _REMOTELOGINSENDCODERES._serialized_end=7925
  _REMOTELOGINCONFIRMCODEREQ._serialized_start=7927
  _REMOTELOGINCONFIRMCODEREQ._serialized_end=7985
  _REMOTELOGINCONFIRMCODERES._serialized_start=7987
  _REMOTELOGINCONFIRMCODERES._serialized_end=8054
  _VERIFYCANCELSIGNINWITHAPPLEREQ._serialized_start=8056
  _VERIFYCANCELSIGNINWITHAPPLEREQ._serialized_end=8140
  _VERIFYCANCELSIGNINWITHAPPLERES._serialized_start=8142
  _VERIFYCANCELSIGNINWITHAPPLERES._serialized_end=8174
  _WECHATCODELOGINTICKETREQ._serialized_start=8176
  _WECHATCODELOGINTICKETREQ._serialized_end=8218
  _WECHATCODELOGINTICKETRES._serialized_start=8220
  _WECHATCODELOGINTICKETRES._serialized_end=8262
  _GETWECHATMINICODEREQ._serialized_start=8264
  _GETWECHATMINICODEREQ._serialized_end=8302
  _GETWECHATMINICODERES._serialized_start=8304
  _GETWECHATMINICODERES._serialized_end=8357
  _GETWECHATMINICODESCANREQ._serialized_start=8359
  _GETWECHATMINICODESCANREQ._serialized_end=8424
  _GETWECHATMINICODESCANRES._serialized_start=8426
  _GETWECHATMINICODESCANRES._serialized_end=8551
  _REFUSEPHONELICENSEREQ._serialized_start=8553
  _REFUSEPHONELICENSEREQ._serialized_end=8593
  _REFUSEPHONELICENSERES._serialized_start=8595
  _REFUSEPHONELICENSERES._serialized_end=8618
  _WECHATMINIBINDPHONEREQ._serialized_start=8620
  _WECHATMINIBINDPHONEREQ._serialized_end=8673
  _WECHATMINIBINDPHONERES._serialized_start=8675
  _WECHATMINIBINDPHONERES._serialized_end=8699
  _THIRDACCOUNTBINDWECHATINFO._serialized_start=8701
  _THIRDACCOUNTBINDWECHATINFO._serialized_end=8747
  _THIRDACCOUNTBINDQQINFO._serialized_start=8749
  _THIRDACCOUNTBINDQQINFO._serialized_end=8791
  _THIRDACCOUNTBINDINFO._serialized_start=8794
  _THIRDACCOUNTBINDINFO._serialized_end=8943
  _THIRDACCOUNTBINDINFODATA._serialized_start=8945
  _THIRDACCOUNTBINDINFODATA._serialized_end=9068
  _THIRDACCOUNTBINDINFOREQ._serialized_start=9070
  _THIRDACCOUNTBINDINFOREQ._serialized_end=9095
  _THIRDACCOUNTBINDINFORES._serialized_start=9097
  _THIRDACCOUNTBINDINFORES._serialized_end=9177
  _BINDTHIRDACCOUNTREQ._serialized_start=9179
  _BINDTHIRDACCOUNTREQ._serialized_end=9303
  _BINDTHIRDACCOUNTRES._serialized_start=9305
  _BINDTHIRDACCOUNTRES._serialized_end=9326
  _UNBINDTHIRDACCOUNTREQ._serialized_start=9328
  _UNBINDTHIRDACCOUNTREQ._serialized_end=9424
  _UNBINDTHIRDACCOUNTRES._serialized_start=9426
  _UNBINDTHIRDACCOUNTRES._serialized_end=9449
  _GETQRCODELOGINCODEREQ._serialized_start=9452
  _GETQRCODELOGINCODEREQ._serialized_end=9614
  _GETQRCODELOGINCODERES._serialized_start=9616
  _GETQRCODELOGINCODERES._serialized_end=9659
  _QRCODESCANLOGINREQ._serialized_start=9661
  _QRCODESCANLOGINREQ._serialized_end=9758
  _QRCODESCANLOGINRES._serialized_start=9760
  _QRCODESCANLOGINRES._serialized_end=9780
  _GETQRCODELOGINSTATUSREQ._serialized_start=9782
  _GETQRCODELOGINSTATUSREQ._serialized_end=9872
  _GETQRCODELOGINSTATUSRES._serialized_start=9875
  _GETQRCODELOGINSTATUSRES._serialized_end=10043
  _SETQRCODELOGINSTATUSREQ._serialized_start=10046
  _SETQRCODELOGINSTATUSREQ._serialized_end=10232
  _SETQRCODELOGINSTATUSRES._serialized_start=10234
  _SETQRCODELOGINSTATUSRES._serialized_end=10259
  _GETACCOUNTREGISTERSTATUSREQ._serialized_start=10261
  _GETACCOUNTREGISTERSTATUSREQ._serialized_end=10381
  _GETACCOUNTREGISTERSTATUSRES._serialized_start=10383
  _GETACCOUNTREGISTERSTATUSRES._serialized_end=10434
  _GETUMENGPHONEREQ._serialized_start=10436
  _GETUMENGPHONEREQ._serialized_end=10486
  _GETUMENGPHONERES._serialized_start=10488
  _GETUMENGPHONERES._serialized_end=10521
  _ACCOUNTCROSSTYPEINFO._serialized_start=10523
  _ACCOUNTCROSSTYPEINFO._serialized_end=10596
  _ACCOUNTCROSSTYPEINFOREQ._serialized_start=10598
  _ACCOUNTCROSSTYPEINFOREQ._serialized_end=10623
  _ACCOUNTCROSSTYPEINFORES._serialized_start=10625
  _ACCOUNTCROSSTYPEINFORES._serialized_end=10701
  _APPLYACCOUNTCROSSTYPEREQ._serialized_start=10703
  _APPLYACCOUNTCROSSTYPEREQ._serialized_end=10729
  _APPLYACCOUNTCROSSTYPERES._serialized_start=10731
  _APPLYACCOUNTCROSSTYPERES._serialized_end=10757
  _CHECKINAPPCHARGELIMITREQ._serialized_start=10759
  _CHECKINAPPCHARGELIMITREQ._serialized_end=10831
  _CHECKINAPPCHARGELIMITRES._serialized_start=10833
  _CHECKINAPPCHARGELIMITRES._serialized_end=10879
  _GETALIPAYMINIORDERREQ._serialized_start=10882
  _GETALIPAYMINIORDERREQ._serialized_end=11162
  _GETALIPAYMINIORDERREQ_EXTENDSENTRY._serialized_start=1365
  _GETALIPAYMINIORDERREQ_EXTENDSENTRY._serialized_end=1411
  _GETALIPAYMINIORDERRES._serialized_start=11164
  _GETALIPAYMINIORDERRES._serialized_end=11205
  _GETGOODSLISTREQ._serialized_start=11207
  _GETGOODSLISTREQ._serialized_end=11240
  _GETGOODSLISTRES._serialized_start=11242
  _GETGOODSLISTRES._serialized_end=11304
  _ALIPAYMINIINDEXITEM._serialized_start=11307
  _ALIPAYMINIINDEXITEM._serialized_end=11489
  _ALIPAYMINIINDEXBANNER._serialized_start=11491
  _ALIPAYMINIINDEXBANNER._serialized_end=11534
  _ALIPAYMINIINDEXGOODSLIST._serialized_start=11536
  _ALIPAYMINIINDEXGOODSLIST._serialized_end=11618
  _ALIPAYMINIINDEXGOODSITEM._serialized_start=11621
  _ALIPAYMINIINDEXGOODSITEM._serialized_end=11794
  _UAUTHEXTOBJ._serialized_start=13788
  _UAUTHEXTOBJ._serialized_end=19830
# @@protoc_insertion_point(module_scope)
